from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Intf import *
from OCC.Core.Adaptor3d import *
from OCC.Core.math import *
from OCC.Core.Adaptor2d import *
from OCC.Core.gp import *
from OCC.Core.IntSurf import *
from OCC.Core.Geom2d import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *
from OCC.Core.IntAna import *

IntPatch_SearchPnt = NewType('IntPatch_SearchPnt', Intf_InterferencePolygon2d)

class IntPatch_SequenceOfIWLineOfTheIWalking:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IntPatch_SequenceOfLine:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class IntPatch_SequenceOfPathPointOfTheSOnBounds:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntPatch_ThePathPointOfTheSOnBounds: ...
    def Last(self) -> IntPatch_ThePathPointOfTheSOnBounds: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntPatch_ThePathPointOfTheSOnBounds) -> IntPatch_ThePathPointOfTheSOnBounds: ...
    def Prepend(self, theItem: IntPatch_ThePathPointOfTheSOnBounds) -> IntPatch_ThePathPointOfTheSOnBounds: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntPatch_ThePathPointOfTheSOnBounds: ...
    def SetValue(self, theIndex: int, theValue: IntPatch_ThePathPointOfTheSOnBounds) -> None: ...

class IntPatch_SequenceOfPoint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntPatch_Point: ...
    def Last(self) -> IntPatch_Point: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntPatch_Point) -> IntPatch_Point: ...
    def Prepend(self, theItem: IntPatch_Point) -> IntPatch_Point: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntPatch_Point: ...
    def SetValue(self, theIndex: int, theValue: IntPatch_Point) -> None: ...

class IntPatch_SequenceOfSegmentOfTheSOnBounds:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> IntPatch_TheSegmentOfTheSOnBounds: ...
    def Last(self) -> IntPatch_TheSegmentOfTheSOnBounds: ...
    def Length(self) -> int: ...
    def Append(self, theItem: IntPatch_TheSegmentOfTheSOnBounds) -> IntPatch_TheSegmentOfTheSOnBounds: ...
    def Prepend(self, theItem: IntPatch_TheSegmentOfTheSOnBounds) -> IntPatch_TheSegmentOfTheSOnBounds: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> IntPatch_TheSegmentOfTheSOnBounds: ...
    def SetValue(self, theIndex: int, theValue: IntPatch_TheSegmentOfTheSOnBounds) -> None: ...

class IntPatch_SpecPntType(IntEnum):
	IntPatch_SPntNone: int = ...
	IntPatch_SPntSeamU: int = ...
	IntPatch_SPntSeamV: int = ...
	IntPatch_SPntSeamUV: int = ...
	IntPatch_SPntPoleSeamU: int = ...
	IntPatch_SPntPole: int = ...
IntPatch_SPntNone = IntPatch_SpecPntType.IntPatch_SPntNone
IntPatch_SPntSeamU = IntPatch_SpecPntType.IntPatch_SPntSeamU
IntPatch_SPntSeamV = IntPatch_SpecPntType.IntPatch_SPntSeamV
IntPatch_SPntSeamUV = IntPatch_SpecPntType.IntPatch_SPntSeamUV
IntPatch_SPntPoleSeamU = IntPatch_SpecPntType.IntPatch_SPntPoleSeamU
IntPatch_SPntPole = IntPatch_SpecPntType.IntPatch_SPntPole

class IntPatch_IType(IntEnum):
	IntPatch_Lin: int = ...
	IntPatch_Circle: int = ...
	IntPatch_Ellipse: int = ...
	IntPatch_Parabola: int = ...
	IntPatch_Hyperbola: int = ...
	IntPatch_Analytic: int = ...
	IntPatch_Walking: int = ...
	IntPatch_Restriction: int = ...
IntPatch_Lin = IntPatch_IType.IntPatch_Lin
IntPatch_Circle = IntPatch_IType.IntPatch_Circle
IntPatch_Ellipse = IntPatch_IType.IntPatch_Ellipse
IntPatch_Parabola = IntPatch_IType.IntPatch_Parabola
IntPatch_Hyperbola = IntPatch_IType.IntPatch_Hyperbola
IntPatch_Analytic = IntPatch_IType.IntPatch_Analytic
IntPatch_Walking = IntPatch_IType.IntPatch_Walking
IntPatch_Restriction = IntPatch_IType.IntPatch_Restriction

class IntPatch_ALineToWLine:
	def __init__(self, theS1: Adaptor3d_HSurface, theS2: Adaptor3d_HSurface, theNbPoints: Optional[int] = 200) -> None: ...
	@overload
	def MakeWLine(self, aline: IntPatch_ALine, theLines: IntPatch_SequenceOfLine) -> None: ...
	@overload
	def MakeWLine(self, aline: IntPatch_ALine, paraminf: float, paramsup: float, theLines: IntPatch_SequenceOfLine) -> None: ...
	def SetTol3D(self, aT: float) -> None: ...
	def SetTolOpenDomain(self, aT: float) -> None: ...
	def SetTolTransition(self, aT: float) -> None: ...
	def Tol3D(self) -> float: ...
	def TolOpenDomain(self) -> float: ...
	def TolTransition(self) -> float: ...

class IntPatch_ArcFunction(math_FunctionWithDerivative):
	def __init__(self) -> None: ...
	def Arc(self) -> Adaptor2d_HCurve2d: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def GetStateNumber(self) -> int: ...
	def LastComputedPoint(self) -> gp_Pnt: ...
	def NbSamples(self) -> int: ...
	def Quadric(self) -> IntSurf_Quadric: ...
	@overload
	def Set(self, A: Adaptor2d_HCurve2d) -> None: ...
	@overload
	def Set(self, S: Adaptor3d_HSurface) -> None: ...
	def SetQuadric(self, Q: IntSurf_Quadric) -> None: ...
	def Surface(self) -> Adaptor3d_HSurface: ...
	def Valpoint(self, Index: int) -> gp_Pnt: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class IntPatch_CSFunction(math_FunctionSetWithDerivatives):
	def __init__(self, S1: Adaptor3d_HSurface, C: Adaptor2d_HCurve2d, S2: Adaptor3d_HSurface) -> None: ...
	def AuxillarCurve(self) -> Adaptor2d_HCurve2d: ...
	def AuxillarSurface(self) -> Adaptor3d_HSurface: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class IntPatch_CurvIntSurf:
	@overload
	def __init__(self, U: float, V: float, W: float, F: IntPatch_CSFunction, TolTangency: float, MarginCoef: Optional[float] = 0.0) -> None: ...
	@overload
	def __init__(self, F: IntPatch_CSFunction, TolTangency: float) -> None: ...
	def Function(self) -> IntPatch_CSFunction: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def ParameterOnCurve(self) -> float: ...
	def ParameterOnSurface(self) -> Tuple[float, float]: ...
	def Perform(self, U: float, V: float, W: float, Rsnld: math_FunctionSetRoot, u0: float, v0: float, u1: float, v1: float, w0: float, w1: float) -> None: ...
	def Point(self) -> gp_Pnt: ...

class IntPatch_HCurve2dTool:
	@staticmethod
	def BSpline(C: Adaptor2d_HCurve2d) -> Geom2d_BSplineCurve: ...
	@staticmethod
	def Bezier(C: Adaptor2d_HCurve2d) -> Geom2d_BezierCurve: ...
	@staticmethod
	def Circle(C: Adaptor2d_HCurve2d) -> gp_Circ2d: ...
	@staticmethod
	def Continuity(C: Adaptor2d_HCurve2d) -> GeomAbs_Shape: ...
	@staticmethod
	def D0(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d) -> None: ...
	@staticmethod
	def D1(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V: gp_Vec2d) -> None: ...
	@staticmethod
	def D2(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@staticmethod
	def D3(C: Adaptor2d_HCurve2d, U: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@staticmethod
	def DN(C: Adaptor2d_HCurve2d, U: float, N: int) -> gp_Vec2d: ...
	@staticmethod
	def Ellipse(C: Adaptor2d_HCurve2d) -> gp_Elips2d: ...
	@staticmethod
	def FirstParameter(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def GetType(C: Adaptor2d_HCurve2d) -> GeomAbs_CurveType: ...
	@staticmethod
	def Hyperbola(C: Adaptor2d_HCurve2d) -> gp_Hypr2d: ...
	@staticmethod
	def Intervals(C: Adaptor2d_HCurve2d, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	@staticmethod
	def IsClosed(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def IsPeriodic(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def LastParameter(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Line(C: Adaptor2d_HCurve2d) -> gp_Lin2d: ...
	@staticmethod
	def NbIntervals(C: Adaptor2d_HCurve2d, S: GeomAbs_Shape) -> int: ...
	@staticmethod
	def NbSamples(C: Adaptor2d_HCurve2d, U0: float, U1: float) -> int: ...
	@staticmethod
	def Parabola(C: Adaptor2d_HCurve2d) -> gp_Parab2d: ...
	@staticmethod
	def Period(C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Resolution(C: Adaptor2d_HCurve2d, R3d: float) -> float: ...
	@staticmethod
	def Value(C: Adaptor2d_HCurve2d, U: float) -> gp_Pnt2d: ...

class IntPatch_HInterTool:
	def __init__(self) -> None: ...
	@staticmethod
	def Bounds(C: Adaptor2d_HCurve2d) -> Tuple[float, float]: ...
	@staticmethod
	def HasBeenSeen(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def HasFirstPoint(C: Adaptor2d_HCurve2d, Index: int) -> Tuple[bool, int]: ...
	@staticmethod
	def HasLastPoint(C: Adaptor2d_HCurve2d, Index: int) -> Tuple[bool, int]: ...
	@staticmethod
	def IsAllSolution(C: Adaptor2d_HCurve2d) -> bool: ...
	@staticmethod
	def IsVertex(C: Adaptor2d_HCurve2d, Index: int) -> bool: ...
	@staticmethod
	def NbPoints(C: Adaptor2d_HCurve2d) -> int: ...
	def NbSamplePoints(self, S: Adaptor3d_HSurface) -> int: ...
	@staticmethod
	def NbSamplesOnArc(A: Adaptor2d_HCurve2d) -> int: ...
	@staticmethod
	def NbSamplesU(S: Adaptor3d_HSurface, u1: float, u2: float) -> int: ...
	@staticmethod
	def NbSamplesV(S: Adaptor3d_HSurface, v1: float, v2: float) -> int: ...
	@staticmethod
	def NbSegments(C: Adaptor2d_HCurve2d) -> int: ...
	@staticmethod
	def Parameter(V: Adaptor3d_HVertex, C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Project(C: Adaptor2d_HCurve2d, P: gp_Pnt2d, Ptproj: gp_Pnt2d) -> Tuple[bool, float]: ...
	def SamplePoint(self, S: Adaptor3d_HSurface, Index: int) -> Tuple[float, float]: ...
	@staticmethod
	def SingularOnUMax(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def SingularOnUMin(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def SingularOnVMax(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def SingularOnVMin(S: Adaptor3d_HSurface) -> bool: ...
	@staticmethod
	def Tolerance(V: Adaptor3d_HVertex, C: Adaptor2d_HCurve2d) -> float: ...
	@staticmethod
	def Value(C: Adaptor2d_HCurve2d, Index: int, Pt: gp_Pnt) -> Tuple[float, float]: ...
	@staticmethod
	def Vertex(C: Adaptor2d_HCurve2d, Index: int, V: Adaptor3d_HVertex) -> None: ...

class IntPatch_ImpImpIntersection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, theIsReqToKeepRLine: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Line(self, Index: int) -> IntPatch_Line: ...
	def NbLines(self) -> int: ...
	def NbPnts(self) -> int: ...
	def OppositeFaces(self) -> bool: ...
	def Perform(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, theIsReqToKeepRLine: Optional[bool] = False) -> None: ...
	def Point(self, Index: int) -> IntPatch_Point: ...
	def TangentFaces(self) -> bool: ...

class IntPatch_ImpPrmIntersection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Surf1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, Surf2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, Fleche: float, Pas: float) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Line(self, Index: int) -> IntPatch_Line: ...
	def NbLines(self) -> int: ...
	def NbPnts(self) -> int: ...
	def Perform(self, Surf1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, Surf2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, Fleche: float, Pas: float) -> None: ...
	def Point(self, Index: int) -> IntPatch_Point: ...
	def SetStartPoint(self, U: float, V: float) -> None: ...

class IntPatch_InterferencePolyhedron(Intf_Interference):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Obje1: IntPatch_Polyhedron, Obje2: IntPatch_Polyhedron) -> None: ...
	@overload
	def __init__(self, Obje: IntPatch_Polyhedron) -> None: ...
	@overload
	def Perform(self, Obje1: IntPatch_Polyhedron, Obje2: IntPatch_Polyhedron) -> None: ...
	@overload
	def Perform(self, Obje: IntPatch_Polyhedron) -> None: ...

class IntPatch_Intersection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float) -> None: ...
	@overload
	def __init__(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, TolArc: float, TolTang: float) -> None: ...
	def Dump(self, Mode: int, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool) -> None: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Line(self, Index: int) -> IntPatch_Line: ...
	def NbLines(self) -> int: ...
	def NbPnts(self) -> int: ...
	def OppositeFaces(self) -> bool: ...
	@overload
	def Perform(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, isGeomInt: Optional[bool] = True, theIsReqToKeepRLine: Optional[bool] = False, theIsReqToPostWLProc: Optional[bool] = True) -> None: ...
	@overload
	def Perform(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, TolArc: float, TolTang: float, LOfPnts: IntSurf_ListOfPntOn2S, isGeomInt: Optional[bool] = True, theIsReqToKeepRLine: Optional[bool] = False, theIsReqToPostWLProc: Optional[bool] = True) -> None: ...
	@overload
	def Perform(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, U1: float, V1: float, U2: float, V2: float, TolArc: float, TolTang: float) -> None: ...
	@overload
	def Perform(self, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, TolArc: float, TolTang: float) -> None: ...
	def Point(self, Index: int) -> IntPatch_Point: ...
	def SequenceOfLine(self) -> IntPatch_SequenceOfLine: ...
	def SetTolerances(self, TolArc: float, TolTang: float, UVMaxStep: float, Fleche: float) -> None: ...
	def TangentFaces(self) -> bool: ...

class IntPatch_Line(Standard_Transient):
	def ArcType(self) -> IntPatch_IType: ...
	def IsTangent(self) -> bool: ...
	def IsUIsoOnS1(self) -> bool: ...
	def IsUIsoOnS2(self) -> bool: ...
	def IsVIsoOnS1(self) -> bool: ...
	def IsVIsoOnS2(self) -> bool: ...
	def SetValue(self, Uiso1: bool, Viso1: bool, Uiso2: bool, Viso2: bool) -> None: ...
	def SituationS1(self) -> IntSurf_Situation: ...
	def SituationS2(self) -> IntSurf_Situation: ...
	def TransitionOnS1(self) -> IntSurf_TypeTrans: ...
	def TransitionOnS2(self) -> IntSurf_TypeTrans: ...

class IntPatch_LineConstructor:
	def __init__(self, mode: int) -> None: ...
	def Line(self, index: int) -> IntPatch_Line: ...
	def NbLines(self) -> int: ...
	def Perform(self, SL: IntPatch_SequenceOfLine, L: IntPatch_Line, S1: Adaptor3d_HSurface, D1: Adaptor3d_TopolTool, S2: Adaptor3d_HSurface, D2: Adaptor3d_TopolTool, Tol: float) -> None: ...

class IntPatch_Point:
	def __init__(self) -> None: ...
	def ArcOnS1(self) -> Adaptor2d_HCurve2d: ...
	def ArcOnS2(self) -> Adaptor2d_HCurve2d: ...
	def Dump(self) -> None: ...
	def IsMultiple(self) -> bool: ...
	def IsOnDomS1(self) -> bool: ...
	def IsOnDomS2(self) -> bool: ...
	def IsTangencyPoint(self) -> bool: ...
	def IsVertexOnS1(self) -> bool: ...
	def IsVertexOnS2(self) -> bool: ...
	def ParameterOnArc1(self) -> float: ...
	def ParameterOnArc2(self) -> float: ...
	def ParameterOnLine(self) -> float: ...
	def Parameters(self) -> Tuple[float, float, float, float]: ...
	def ParametersOnS1(self) -> Tuple[float, float]: ...
	def ParametersOnS2(self) -> Tuple[float, float]: ...
	def PntOn2S(self) -> IntSurf_PntOn2S: ...
	def ReverseTransition(self) -> None: ...
	def SetArc(self, OnFirst: bool, A: Adaptor2d_HCurve2d, Param: float, TLine: IntSurf_Transition, TArc: IntSurf_Transition) -> None: ...
	def SetMultiple(self, IsMult: bool) -> None: ...
	def SetParameter(self, Para: float) -> None: ...
	def SetParameters(self, U1: float, V1: float, U2: float, V2: float) -> None: ...
	def SetTolerance(self, Tol: float) -> None: ...
	@overload
	def SetValue(self, Pt: gp_Pnt, Tol: float, Tangent: bool) -> None: ...
	@overload
	def SetValue(self, Pt: gp_Pnt) -> None: ...
	@overload
	def SetValue(self, thePOn2S: IntSurf_PntOn2S) -> None: ...
	def SetVertex(self, OnFirst: bool, V: Adaptor3d_HVertex) -> None: ...
	def Tolerance(self) -> float: ...
	def TransitionLineArc1(self) -> IntSurf_Transition: ...
	def TransitionLineArc2(self) -> IntSurf_Transition: ...
	def TransitionOnS1(self) -> IntSurf_Transition: ...
	def TransitionOnS2(self) -> IntSurf_Transition: ...
	def Value(self) -> gp_Pnt: ...
	def VertexOnS1(self) -> Adaptor3d_HVertex: ...
	def VertexOnS2(self) -> Adaptor3d_HVertex: ...

class IntPatch_Polygo(Intf_Polygon2d):
	def DeflectionOverEstimation(self) -> float: ...
	def Dump(self) -> None: ...
	def Error(self) -> float: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def Point(self, Index: int) -> gp_Pnt2d: ...
	def Segment(self, theIndex: int, theBegin: gp_Pnt2d, theEnd: gp_Pnt2d) -> None: ...

class IntPatch_PolyhedronTool:
	@staticmethod
	def Bounding(thePolyh: IntPatch_Polyhedron) -> Bnd_Box: ...
	@staticmethod
	def ComponentsBounding(thePolyh: IntPatch_Polyhedron) -> Bnd_HArray1OfBox: ...
	@staticmethod
	def DeflectionOverEstimation(thePolyh: IntPatch_Polyhedron) -> float: ...
	@staticmethod
	def NbTriangles(thePolyh: IntPatch_Polyhedron) -> int: ...
	@staticmethod
	def Point(thePolyh: IntPatch_Polyhedron, Index: int) -> gp_Pnt: ...
	@staticmethod
	def TriConnex(thePolyh: IntPatch_Polyhedron, Triang: int, Pivot: int, Pedge: int) -> Tuple[int, int, int]: ...
	@staticmethod
	def Triangle(thePolyh: IntPatch_Polyhedron, Index: int) -> Tuple[int, int, int]: ...

class IntPatch_PrmPrmIntersection:
	def __init__(self) -> None: ...
	def CodeReject(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, x3: float, y3: float, z3: float) -> int: ...
	def DansGrille(self, t: int) -> int: ...
	def GrilleInteger(self, ix: int, iy: int, iz: int) -> int: ...
	def IntegerGrille(self, t: int) -> Tuple[int, int, int]: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def Line(self, Index: int) -> IntPatch_Line: ...
	def NbLines(self) -> int: ...
	def NbPointsGrille(self) -> int: ...
	def NewLine(self, Caro1: Adaptor3d_HSurface, Caro2: Adaptor3d_HSurface, IndexLine: int, LowPoint: int, HighPoint: int, NbPoints: int) -> IntPatch_Line: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Polyhedron1: IntPatch_Polyhedron, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Polyhedron2: IntPatch_Polyhedron, Domain2: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Polyhedron1: IntPatch_Polyhedron, Domain1: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Domain2: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float, ClearFlag: Optional[bool] = True) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Domain2: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float, ListOfPnts: IntSurf_ListOfPntOn2S) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Domain2: Adaptor3d_TopolTool, U1: float, V1: float, U2: float, V2: float, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Domain1: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Polyhedron2: IntPatch_Polyhedron, Domain2: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	@overload
	def Perform(self, Caro1: Adaptor3d_HSurface, Polyhedron1: IntPatch_Polyhedron, Domain1: Adaptor3d_TopolTool, Caro2: Adaptor3d_HSurface, Domain2: Adaptor3d_TopolTool, TolTangency: float, Epsilon: float, Deflection: float, Increment: float) -> None: ...
	def PointDepart(self, LineOn2S: IntSurf_LineOn2S, S1: Adaptor3d_HSurface, SU1: int, SV1: int, S2: Adaptor3d_HSurface, SU2: int, SV2: int) -> None: ...
	def Remplit(self, a: int, b: int, c: int, Map: IntPatch_PrmPrmIntersection_T3Bits) -> None: ...
	def RemplitLin(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int, Map: IntPatch_PrmPrmIntersection_T3Bits) -> None: ...
	def RemplitTri(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int, x3: int, y3: int, z3: int, Map: IntPatch_PrmPrmIntersection_T3Bits) -> None: ...

class IntPatch_PrmPrmIntersection_T3Bits:
	def __init__(self, size: int) -> None: ...
	def Add(self, t: int) -> None: ...
	def And(self, Oth: IntPatch_PrmPrmIntersection_T3Bits) -> Tuple[int, int]: ...
	def Destroy(self) -> None: ...
	def Raz(self, t: int) -> None: ...
	def ResetAnd(self) -> None: ...
	def Val(self, t: int) -> int: ...

class IntPatch_RstInt:
	@staticmethod
	def PutVertexOnLine(L: IntPatch_Line, Surf: Adaptor3d_HSurface, Domain: Adaptor3d_TopolTool, OtherSurf: Adaptor3d_HSurface, OnFirst: bool, Tol: float) -> None: ...

class IntPatch_SpecialPoints:
	@staticmethod
	def AddCrossUVIsoPoint(theQSurf: Adaptor3d_HSurface, thePSurf: Adaptor3d_HSurface, theRefPt: IntSurf_PntOn2S, theTol3d: float, theAddedPoint: IntSurf_PntOn2S, theIsReversed: Optional[bool] = False) -> bool: ...
	@staticmethod
	def AddPointOnUorVIso(theQSurf: Adaptor3d_HSurface, thePSurf: Adaptor3d_HSurface, theRefPt: IntSurf_PntOn2S, theIsU: bool, theIsoParameter: float, theToler: math_Vector, theInitPoint: math_Vector, theInfBound: math_Vector, theSupBound: math_Vector, theAddedPoint: IntSurf_PntOn2S, theIsReversed: Optional[bool] = False) -> bool: ...
	@staticmethod
	def AddSingularPole(theQSurf: Adaptor3d_HSurface, thePSurf: Adaptor3d_HSurface, thePtIso: IntSurf_PntOn2S, theVertex: IntPatch_Point, theAddedPoint: IntSurf_PntOn2S, theIsReversed: Optional[bool] = False, theIsReqRefCheck: Optional[bool] = False) -> bool: ...
	@staticmethod
	def AdjustPointAndVertex(theRefPoint: IntSurf_PntOn2S, theArrPeriods_list: List[float], theNewPoint: IntSurf_PntOn2S, theVertex: Optional[IntPatch_Point] = 0) -> None: ...
	@staticmethod
	def ContinueAfterSpecialPoint(theQSurf: Adaptor3d_HSurface, thePSurf: Adaptor3d_HSurface, theRefPt: IntSurf_PntOn2S, theSPType: IntPatch_SpecPntType, theTol2D: float, theNewPoint: IntSurf_PntOn2S, theIsReversed: Optional[bool] = False) -> bool: ...

class IntPatch_TheIWLineOfTheIWalking(Standard_Transient):
	def __init__(self, theAllocator: Optional[IntSurf_Allocator] = 0) -> None: ...
	def AddIndexPassing(self, Index: int) -> None: ...
	def AddPoint(self, P: IntSurf_PntOn2S) -> None: ...
	@overload
	def AddStatusFirst(self, Closed: bool, HasFirst: bool) -> None: ...
	@overload
	def AddStatusFirst(self, Closed: bool, HasLast: bool, Index: int, P: IntSurf_PathPoint) -> None: ...
	def AddStatusFirstLast(self, Closed: bool, HasFirst: bool, HasLast: bool) -> None: ...
	@overload
	def AddStatusLast(self, HasLast: bool) -> None: ...
	@overload
	def AddStatusLast(self, HasLast: bool, Index: int, P: IntSurf_PathPoint) -> None: ...
	def Cut(self, Index: int) -> None: ...
	def FirstPoint(self) -> IntSurf_PathPoint: ...
	def FirstPointIndex(self) -> int: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def IsClosed(self) -> bool: ...
	def IsTangentAtBegining(self) -> bool: ...
	def IsTangentAtEnd(self) -> bool: ...
	def LastPoint(self) -> IntSurf_PathPoint: ...
	def LastPointIndex(self) -> int: ...
	def Line(self) -> IntSurf_LineOn2S: ...
	def NbPassingPoint(self) -> int: ...
	def NbPoints(self) -> int: ...
	def PassingPoint(self, Index: int) -> Tuple[int, int]: ...
	def Reverse(self) -> None: ...
	def SetTangencyAtBegining(self, IsTangent: bool) -> None: ...
	def SetTangencyAtEnd(self, IsTangent: bool) -> None: ...
	def SetTangentVector(self, V: gp_Vec, Index: int) -> None: ...
	def TangentVector(self) -> Tuple[gp_Vec, int]: ...
	def Value(self, Index: int) -> IntSurf_PntOn2S: ...

class IntPatch_TheIWalking:
	def __init__(self, Epsilon: float, Deflection: float, Step: float, theToFillHoles: Optional[bool] = False) -> None: ...
	def IsDone(self) -> bool: ...
	def NbLines(self) -> int: ...
	def NbSinglePnts(self) -> int: ...
	@overload
	def Perform(self, Pnts1: IntSurf_SequenceOfPathPoint, Pnts2: IntSurf_SequenceOfInteriorPoint, Func: IntPatch_TheSurfFunction, S: Adaptor3d_HSurface, Reversed: Optional[bool] = False) -> None: ...
	@overload
	def Perform(self, Pnts1: IntSurf_SequenceOfPathPoint, Func: IntPatch_TheSurfFunction, S: Adaptor3d_HSurface, Reversed: Optional[bool] = False) -> None: ...
	def SetTolerance(self, Epsilon: float, Deflection: float, Step: float) -> None: ...
	def SinglePnt(self, Index: int) -> IntSurf_PathPoint: ...
	def Value(self, Index: int) -> IntPatch_TheIWLineOfTheIWalking: ...

class IntPatch_ThePathPointOfTheSOnBounds:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Tol: float, V: Adaptor3d_HVertex, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt, Tol: float, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	def Arc(self) -> Adaptor2d_HCurve2d: ...
	def IsNew(self) -> bool: ...
	def Parameter(self) -> float: ...
	@overload
	def SetValue(self, P: gp_Pnt, Tol: float, V: Adaptor3d_HVertex, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	@overload
	def SetValue(self, P: gp_Pnt, Tol: float, A: Adaptor2d_HCurve2d, Parameter: float) -> None: ...
	def Tolerance(self) -> float: ...
	def Value(self) -> gp_Pnt: ...
	def Vertex(self) -> Adaptor3d_HVertex: ...

class IntPatch_TheSOnBounds:
	def __init__(self) -> None: ...
	def AllArcSolution(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def NbSegments(self) -> int: ...
	def Perform(self, F: IntPatch_ArcFunction, Domain: Adaptor3d_TopolTool, TolBoundary: float, TolTangency: float, RecheckOnRegularity: Optional[bool] = False) -> None: ...
	def Point(self, Index: int) -> IntPatch_ThePathPointOfTheSOnBounds: ...
	def Segment(self, Index: int) -> IntPatch_TheSegmentOfTheSOnBounds: ...

class IntPatch_TheSearchInside:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: IntPatch_TheSurfFunction, Surf: Adaptor3d_HSurface, T: Adaptor3d_TopolTool, Epsilon: float) -> None: ...
	def IsDone(self) -> bool: ...
	def NbPoints(self) -> int: ...
	@overload
	def Perform(self, F: IntPatch_TheSurfFunction, Surf: Adaptor3d_HSurface, T: Adaptor3d_TopolTool, Epsilon: float) -> None: ...
	@overload
	def Perform(self, F: IntPatch_TheSurfFunction, Surf: Adaptor3d_HSurface, UStart: float, VStart: float) -> None: ...
	def Value(self, Index: int) -> IntSurf_InteriorPoint: ...

class IntPatch_TheSegmentOfTheSOnBounds:
	def __init__(self) -> None: ...
	def Curve(self) -> Adaptor2d_HCurve2d: ...
	def FirstPoint(self) -> IntPatch_ThePathPointOfTheSOnBounds: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def LastPoint(self) -> IntPatch_ThePathPointOfTheSOnBounds: ...
	def SetLimitPoint(self, V: IntPatch_ThePathPointOfTheSOnBounds, First: bool) -> None: ...
	def SetValue(self, A: Adaptor2d_HCurve2d) -> None: ...

class IntPatch_TheSurfFunction(math_FunctionSetWithDerivatives):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, PS: Adaptor3d_HSurface, IS: IntSurf_Quadric) -> None: ...
	@overload
	def __init__(self, IS: IntSurf_Quadric) -> None: ...
	def Derivatives(self, X: math_Vector, D: math_Matrix) -> bool: ...
	def Direction2d(self) -> gp_Dir2d: ...
	def Direction3d(self) -> gp_Vec: ...
	def ISurface(self) -> IntSurf_Quadric: ...
	def IsTangent(self) -> bool: ...
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def PSurface(self) -> Adaptor3d_HSurface: ...
	def Point(self) -> gp_Pnt: ...
	def Root(self) -> float: ...
	@overload
	def Set(self, PS: Adaptor3d_HSurface) -> None: ...
	@overload
	def Set(self, Tolerance: float) -> None: ...
	def SetImplicitSurface(self, IS: IntSurf_Quadric) -> None: ...
	def Tolerance(self) -> float: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...
	def Values(self, X: math_Vector, F: math_Vector, D: math_Matrix) -> bool: ...

class IntPatch_WLineTool:
	@staticmethod
	def ComputePurgedWLine(theWLine: IntPatch_WLine, theS1: Adaptor3d_HSurface, theS2: Adaptor3d_HSurface, theDom1: Adaptor3d_TopolTool, theDom2: Adaptor3d_TopolTool) -> IntPatch_WLine: ...
	@staticmethod
	def JoinWLines(theSlin: IntPatch_SequenceOfLine, theSPnt: IntPatch_SequenceOfPoint, theS1: Adaptor3d_HSurface, theS2: Adaptor3d_HSurface, theTol3D: float) -> None: ...

class IntPatch_ALine(IntPatch_Line):
	@overload
	def __init__(self, C: IntAna_Curve, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, C: IntAna_Curve, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, C: IntAna_Curve, Tang: bool) -> None: ...
	def AddVertex(self, Pnt: IntPatch_Point) -> None: ...
	def ChangeVertex(self, theIndex: int) -> IntPatch_Point: ...
	def ComputeVertexParameters(self, Tol: float) -> None: ...
	def Curve(self) -> IntAna_Curve: ...
	def D1(self, U: float, P: gp_Pnt, Du: gp_Vec) -> bool: ...
	def FindParameter(self, P: gp_Pnt, theParams: TColStd_ListOfReal) -> None: ...
	def FirstParameter(self) -> Tuple[float, bool]: ...
	def FirstPoint(self) -> IntPatch_Point: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def LastParameter(self) -> Tuple[float, bool]: ...
	def LastPoint(self) -> IntPatch_Point: ...
	def NbVertex(self) -> int: ...
	def Replace(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def SetFirstPoint(self, IndFirst: int) -> None: ...
	def SetLastPoint(self, IndLast: int) -> None: ...
	def Value(self, U: float) -> gp_Pnt: ...
	def Vertex(self, Index: int) -> IntPatch_Point: ...

class IntPatch_GLine(IntPatch_Line):
	@overload
	def __init__(self, L: gp_Lin, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, L: gp_Lin, Tang: bool) -> None: ...
	@overload
	def __init__(self, C: gp_Circ, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, C: gp_Circ, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, C: gp_Circ, Tang: bool) -> None: ...
	@overload
	def __init__(self, E: gp_Elips, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, E: gp_Elips, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, E: gp_Elips, Tang: bool) -> None: ...
	@overload
	def __init__(self, P: gp_Parab, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, P: gp_Parab, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, P: gp_Parab, Tang: bool) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr, Tang: bool) -> None: ...
	def AddVertex(self, Pnt: IntPatch_Point) -> None: ...
	def Circle(self) -> gp_Circ: ...
	def ComputeVertexParameters(self, Tol: float) -> None: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstPoint(self) -> IntPatch_Point: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def LastPoint(self) -> IntPatch_Point: ...
	def Line(self) -> gp_Lin: ...
	def NbVertex(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Replace(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def SetFirstPoint(self, IndFirst: int) -> None: ...
	def SetLastPoint(self, IndLast: int) -> None: ...
	def Vertex(self, Index: int) -> IntPatch_Point: ...

class IntPatch_PointLine(IntPatch_Line):
	def AddVertex(self, Pnt: IntPatch_Point, theIsPrepend: Optional[bool] = False) -> None: ...
	def ChangeVertex(self, Index: int) -> IntPatch_Point: ...
	def ClearVertexes(self) -> None: ...
	@staticmethod
	def CurvatureRadiusOfIntersLine(theS1: Adaptor3d_HSurface, theS2: Adaptor3d_HSurface, theUVPoint: IntSurf_PntOn2S) -> float: ...
	def Curve(self) -> IntSurf_LineOn2S: ...
	def IsOutBox(self, P: gp_Pnt) -> bool: ...
	def IsOutSurf1Box(self, P1: gp_Pnt2d) -> bool: ...
	def IsOutSurf2Box(self, P2: gp_Pnt2d) -> bool: ...
	def NbPnts(self) -> int: ...
	def NbVertex(self) -> int: ...
	def Point(self, Index: int) -> IntSurf_PntOn2S: ...
	def RemoveVertex(self, theIndex: int) -> None: ...
	def Vertex(self, Index: int) -> IntPatch_Point: ...

class IntPatch_PolyArc(IntPatch_Polygo):
	def __init__(self, A: Adaptor2d_HCurve2d, NbSample: int, Pfirst: float, Plast: float, BoxOtherPolygon: Bnd_Box2d) -> None: ...
	def Closed(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def Parameter(self, Index: int) -> float: ...
	def Point(self, Index: int) -> gp_Pnt2d: ...
	def SetOffset(self, OffsetX: float, OffsetY: float) -> None: ...

class IntPatch_PolyLine(IntPatch_Polygo):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, InitDefle: float) -> None: ...
	def NbPoints(self) -> int: ...
	def Point(self, Index: int) -> gp_Pnt2d: ...
	def ResetError(self) -> None: ...
	def SetRLine(self, OnFirst: bool, Line: IntPatch_RLine) -> None: ...
	def SetWLine(self, OnFirst: bool, Line: IntPatch_WLine) -> None: ...

class IntPatch_RLine(IntPatch_PointLine):
	@overload
	def __init__(self, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, Tang: bool) -> None: ...
	def Add(self, L: IntSurf_LineOn2S) -> None: ...
	def AddVertex(self, Pnt: IntPatch_Point, theIsPrepend: Optional[bool] = False) -> None: ...
	def ArcOnS1(self) -> Adaptor2d_HCurve2d: ...
	def ArcOnS2(self) -> Adaptor2d_HCurve2d: ...
	def ChangeVertex(self, Index: int) -> IntPatch_Point: ...
	def ClearVertexes(self) -> None: ...
	def ComputeVertexParameters(self, Tol: float) -> None: ...
	def Curve(self) -> IntSurf_LineOn2S: ...
	def Dump(self, theMode: int) -> None: ...
	def FirstPoint(self) -> IntPatch_Point: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def HasPolygon(self) -> bool: ...
	def IsArcOnS1(self) -> bool: ...
	def IsArcOnS2(self) -> bool: ...
	def IsOutBox(self, theP: gp_Pnt) -> bool: ...
	def IsOutSurf1Box(self, theP: gp_Pnt2d) -> bool: ...
	def IsOutSurf2Box(self, theP: gp_Pnt2d) -> bool: ...
	def LastPoint(self) -> IntPatch_Point: ...
	def NbPnts(self) -> int: ...
	def NbVertex(self) -> int: ...
	def ParamOnS1(self) -> Tuple[float, float]: ...
	def ParamOnS2(self) -> Tuple[float, float]: ...
	def Point(self, Index: int) -> IntSurf_PntOn2S: ...
	def RemoveVertex(self, theIndex: int) -> None: ...
	def Replace(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def SetArcOnS1(self, A: Adaptor2d_HCurve2d) -> None: ...
	def SetArcOnS2(self, A: Adaptor2d_HCurve2d) -> None: ...
	def SetCurve(self, theNewCurve: IntSurf_LineOn2S) -> None: ...
	def SetFirstPoint(self, IndFirst: int) -> None: ...
	def SetLastPoint(self, IndLast: int) -> None: ...
	def SetPoint(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def Vertex(self, Index: int) -> IntPatch_Point: ...

class IntPatch_WLine(IntPatch_PointLine):
	@overload
	def __init__(self, Line: IntSurf_LineOn2S, Tang: bool, Trans1: IntSurf_TypeTrans, Trans2: IntSurf_TypeTrans) -> None: ...
	@overload
	def __init__(self, Line: IntSurf_LineOn2S, Tang: bool, Situ1: IntSurf_Situation, Situ2: IntSurf_Situation) -> None: ...
	@overload
	def __init__(self, Line: IntSurf_LineOn2S, Tang: bool) -> None: ...
	def AddVertex(self, Pnt: IntPatch_Point, theIsPrepend: Optional[bool] = False) -> None: ...
	def ChangeVertex(self, Index: int) -> IntPatch_Point: ...
	def ClearVertexes(self) -> None: ...
	def ComputeVertexParameters(self, Tol: float) -> None: ...
	def Curve(self) -> IntSurf_LineOn2S: ...
	def Dump(self, theMode: int) -> None: ...
	def EnablePurging(self, theIsEnabled: bool) -> None: ...
	@overload
	def FirstPoint(self) -> IntPatch_Point: ...
	@overload
	def FirstPoint(self) -> Tuple[IntPatch_Point, int]: ...
	def GetArcOnS1(self) -> Adaptor2d_HCurve2d: ...
	def GetArcOnS2(self) -> Adaptor2d_HCurve2d: ...
	def GetCreatingWay(self) -> False: ...
	def HasArcOnS1(self) -> bool: ...
	def HasArcOnS2(self) -> bool: ...
	def HasFirstPoint(self) -> bool: ...
	def HasLastPoint(self) -> bool: ...
	def InsertVertexBefore(self, theIndex: int, thePnt: IntPatch_Point) -> None: ...
	def IsOutBox(self, theP: gp_Pnt) -> bool: ...
	def IsOutSurf1Box(self, theP: gp_Pnt2d) -> bool: ...
	def IsOutSurf2Box(self, theP: gp_Pnt2d) -> bool: ...
	def IsPurgingAllowed(self) -> bool: ...
	@overload
	def LastPoint(self) -> IntPatch_Point: ...
	@overload
	def LastPoint(self) -> Tuple[IntPatch_Point, int]: ...
	def NbPnts(self) -> int: ...
	def NbVertex(self) -> int: ...
	def Point(self, Index: int) -> IntSurf_PntOn2S: ...
	def RemoveVertex(self, theIndex: int) -> None: ...
	def Replace(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def SetArcOnS1(self, A: Adaptor2d_HCurve2d) -> None: ...
	def SetArcOnS2(self, A: Adaptor2d_HCurve2d) -> None: ...
	def SetCreatingWayInfo(self, theAlgo: IntPatch_WLType) -> None: ...
	def SetFirstPoint(self, IndFirst: int) -> None: ...
	def SetLastPoint(self, IndLast: int) -> None: ...
	def SetPeriod(self, pu1: float, pv1: float, pu2: float, pv2: float) -> None: ...
	def SetPoint(self, Index: int, Pnt: IntPatch_Point) -> None: ...
	def U1Period(self) -> float: ...
	def U2Period(self) -> float: ...
	def V1Period(self) -> float: ...
	def V2Period(self) -> float: ...
	def Vertex(self, Index: int) -> IntPatch_Point: ...

#classnotwrapped
class IntPatch_Polyhedron: ...

# harray1 classes
# harray2 classes
# hsequence classes

IntPatch_HCurve2dTool_BSpline = IntPatch_HCurve2dTool.BSpline
IntPatch_HCurve2dTool_Bezier = IntPatch_HCurve2dTool.Bezier
IntPatch_HCurve2dTool_Circle = IntPatch_HCurve2dTool.Circle
IntPatch_HCurve2dTool_Continuity = IntPatch_HCurve2dTool.Continuity
IntPatch_HCurve2dTool_D0 = IntPatch_HCurve2dTool.D0
IntPatch_HCurve2dTool_D1 = IntPatch_HCurve2dTool.D1
IntPatch_HCurve2dTool_D2 = IntPatch_HCurve2dTool.D2
IntPatch_HCurve2dTool_D3 = IntPatch_HCurve2dTool.D3
IntPatch_HCurve2dTool_DN = IntPatch_HCurve2dTool.DN
IntPatch_HCurve2dTool_Ellipse = IntPatch_HCurve2dTool.Ellipse
IntPatch_HCurve2dTool_FirstParameter = IntPatch_HCurve2dTool.FirstParameter
IntPatch_HCurve2dTool_GetType = IntPatch_HCurve2dTool.GetType
IntPatch_HCurve2dTool_Hyperbola = IntPatch_HCurve2dTool.Hyperbola
IntPatch_HCurve2dTool_Intervals = IntPatch_HCurve2dTool.Intervals
IntPatch_HCurve2dTool_IsClosed = IntPatch_HCurve2dTool.IsClosed
IntPatch_HCurve2dTool_IsPeriodic = IntPatch_HCurve2dTool.IsPeriodic
IntPatch_HCurve2dTool_LastParameter = IntPatch_HCurve2dTool.LastParameter
IntPatch_HCurve2dTool_Line = IntPatch_HCurve2dTool.Line
IntPatch_HCurve2dTool_NbIntervals = IntPatch_HCurve2dTool.NbIntervals
IntPatch_HCurve2dTool_NbSamples = IntPatch_HCurve2dTool.NbSamples
IntPatch_HCurve2dTool_Parabola = IntPatch_HCurve2dTool.Parabola
IntPatch_HCurve2dTool_Period = IntPatch_HCurve2dTool.Period
IntPatch_HCurve2dTool_Resolution = IntPatch_HCurve2dTool.Resolution
IntPatch_HCurve2dTool_Value = IntPatch_HCurve2dTool.Value
IntPatch_HInterTool_Bounds = IntPatch_HInterTool.Bounds
IntPatch_HInterTool_HasBeenSeen = IntPatch_HInterTool.HasBeenSeen
IntPatch_HInterTool_HasFirstPoint = IntPatch_HInterTool.HasFirstPoint
IntPatch_HInterTool_HasLastPoint = IntPatch_HInterTool.HasLastPoint
IntPatch_HInterTool_IsAllSolution = IntPatch_HInterTool.IsAllSolution
IntPatch_HInterTool_IsVertex = IntPatch_HInterTool.IsVertex
IntPatch_HInterTool_NbPoints = IntPatch_HInterTool.NbPoints
IntPatch_HInterTool_NbSamplesOnArc = IntPatch_HInterTool.NbSamplesOnArc
IntPatch_HInterTool_NbSamplesU = IntPatch_HInterTool.NbSamplesU
IntPatch_HInterTool_NbSamplesV = IntPatch_HInterTool.NbSamplesV
IntPatch_HInterTool_NbSegments = IntPatch_HInterTool.NbSegments
IntPatch_HInterTool_Parameter = IntPatch_HInterTool.Parameter
IntPatch_HInterTool_Project = IntPatch_HInterTool.Project
IntPatch_HInterTool_SingularOnUMax = IntPatch_HInterTool.SingularOnUMax
IntPatch_HInterTool_SingularOnUMin = IntPatch_HInterTool.SingularOnUMin
IntPatch_HInterTool_SingularOnVMax = IntPatch_HInterTool.SingularOnVMax
IntPatch_HInterTool_SingularOnVMin = IntPatch_HInterTool.SingularOnVMin
IntPatch_HInterTool_Tolerance = IntPatch_HInterTool.Tolerance
IntPatch_HInterTool_Value = IntPatch_HInterTool.Value
IntPatch_HInterTool_Vertex = IntPatch_HInterTool.Vertex
IntPatch_PolyhedronTool_Bounding = IntPatch_PolyhedronTool.Bounding
IntPatch_PolyhedronTool_ComponentsBounding = IntPatch_PolyhedronTool.ComponentsBounding
IntPatch_PolyhedronTool_DeflectionOverEstimation = IntPatch_PolyhedronTool.DeflectionOverEstimation
IntPatch_PolyhedronTool_NbTriangles = IntPatch_PolyhedronTool.NbTriangles
IntPatch_PolyhedronTool_Point = IntPatch_PolyhedronTool.Point
IntPatch_PolyhedronTool_TriConnex = IntPatch_PolyhedronTool.TriConnex
IntPatch_PolyhedronTool_Triangle = IntPatch_PolyhedronTool.Triangle
IntPatch_RstInt_PutVertexOnLine = IntPatch_RstInt.PutVertexOnLine
IntPatch_SpecialPoints_AddCrossUVIsoPoint = IntPatch_SpecialPoints.AddCrossUVIsoPoint
IntPatch_SpecialPoints_AddPointOnUorVIso = IntPatch_SpecialPoints.AddPointOnUorVIso
IntPatch_SpecialPoints_AddSingularPole = IntPatch_SpecialPoints.AddSingularPole
IntPatch_SpecialPoints_AdjustPointAndVertex = IntPatch_SpecialPoints.AdjustPointAndVertex
IntPatch_SpecialPoints_ContinueAfterSpecialPoint = IntPatch_SpecialPoints.ContinueAfterSpecialPoint
IntPatch_WLineTool_ComputePurgedWLine = IntPatch_WLineTool.ComputePurgedWLine
IntPatch_WLineTool_ExtendTwoWLines = IntPatch_WLineTool.ExtendTwoWLines
IntPatch_WLineTool_JoinWLines = IntPatch_WLineTool.JoinWLines
IntPatch_PointLine_CurvatureRadiusOfIntersLine = IntPatch_PointLine.CurvatureRadiusOfIntersLine



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
NCollection module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_ncollection.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _NCollection
else:
    import _NCollection

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _NCollection.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _NCollection.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _NCollection.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _NCollection.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _NCollection.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _NCollection.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _NCollection.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _NCollection.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _NCollection.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _NCollection.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _NCollection.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _NCollection.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _NCollection.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _NCollection.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _NCollection.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _NCollection.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _NCollection.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _NCollection:
_NCollection.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _NCollection.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard

from enum import IntEnum
from OCC.Core.Exception import *



class NCollection_Utf16Iter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, theString: "char16_t const *"):
        _NCollection.NCollection_Utf16Iter_swiginit(self, _NCollection.new_NCollection_Utf16Iter(theString))

    def Init(self, theString: "char16_t const *") -> "void":
        return _NCollection.NCollection_Utf16Iter_Init(self, theString)

    def __eq__(self, theRight: "NCollection_Utf16Iter") -> "bool":
        return _NCollection.NCollection_Utf16Iter___eq__(self, theRight)

    def IsValid(self) -> "bool":
        return _NCollection.NCollection_Utf16Iter_IsValid(self)

    def __ref__(self) -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf16Iter___ref__(self)

    def BufferHere(self) -> "char16_t const *":
        return _NCollection.NCollection_Utf16Iter_BufferHere(self)

    def ChangeBufferHere(self) -> "char16_t *":
        return _NCollection.NCollection_Utf16Iter_ChangeBufferHere(self)

    def BufferNext(self) -> "char16_t const *":
        return _NCollection.NCollection_Utf16Iter_BufferNext(self)

    def Index(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16Iter_Index(self)

    def AdvanceBytesUtf8(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16Iter_AdvanceBytesUtf8(self)

    def AdvanceBytesUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16Iter_AdvanceBytesUtf16(self)

    def AdvanceCodeUnitsUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16Iter_AdvanceCodeUnitsUtf16(self)

    def AdvanceBytesUtf32(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16Iter_AdvanceBytesUtf32(self)

    def GetUtf8(self, *args) -> "Standard_Utf8UChar *":
        return _NCollection.NCollection_Utf16Iter_GetUtf8(self, *args)

    def GetUtf16(self, theBuffer: "Standard_Utf16Char *") -> "Standard_Utf16Char *":
        return _NCollection.NCollection_Utf16Iter_GetUtf16(self, theBuffer)

    def GetUtf32(self, theBuffer: "Standard_Utf32Char *") -> "Standard_Utf32Char *":
        return _NCollection.NCollection_Utf16Iter_GetUtf32(self, theBuffer)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf16Iter

# Register NCollection_Utf16Iter in _NCollection:
_NCollection.NCollection_Utf16Iter_swigregister(NCollection_Utf16Iter)

class NCollection_Utf16String(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Iterator(self) -> "NCollection_UtfIterator< char16_t >":
        return _NCollection.NCollection_Utf16String_Iterator(self)

    def Size(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16String_Size(self)

    def Length(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf16String_Length(self)

    def GetChar(self, theCharIndex: "Standard_Integer const") -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf16String_GetChar(self, theCharIndex)

    def GetCharBuffer(self, theCharIndex: "Standard_Integer const") -> "char16_t const *":
        return _NCollection.NCollection_Utf16String_GetCharBuffer(self, theCharIndex)

    def __init__(self, *args):
        _NCollection.NCollection_Utf16String_swiginit(self, _NCollection.new_NCollection_Utf16String(*args))

    def FromLocale(self, theString: "char const *", theLength: "Standard_Integer const"=-1) -> "void":
        return _NCollection.NCollection_Utf16String_FromLocale(self, theString, theLength)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf16String

    def IsEqual(self, theCompare: "NCollection_Utf16String") -> "bool":
        return _NCollection.NCollection_Utf16String_IsEqual(self, theCompare)

    def SubString(self, theStart: "Standard_Integer const", theEnd: "Standard_Integer const") -> "NCollection_UtfString< Standard_Utf16Char >":
        return _NCollection.NCollection_Utf16String_SubString(self, theStart, theEnd)

    def ToCString(self) -> "char16_t const *":
        return _NCollection.NCollection_Utf16String_ToCString(self)

    def ToUtf8(self) -> "NCollection_UtfString< Standard_Utf8Char > const":
        return _NCollection.NCollection_Utf16String_ToUtf8(self)

    def ToUtf16(self) -> "NCollection_UtfString< Standard_Utf16Char > const":
        return _NCollection.NCollection_Utf16String_ToUtf16(self)

    def ToUtf32(self) -> "NCollection_UtfString< Standard_Utf32Char > const":
        return _NCollection.NCollection_Utf16String_ToUtf32(self)

    def ToUtfWide(self) -> "NCollection_UtfString< Standard_WideChar > const":
        return _NCollection.NCollection_Utf16String_ToUtfWide(self)

    def ToLocale(self, theBuffer: "char *", theSizeBytes: "Standard_Integer const") -> "bool":
        return _NCollection.NCollection_Utf16String_ToLocale(self, theBuffer, theSizeBytes)

    def IsEmpty(self) -> "bool":
        return _NCollection.NCollection_Utf16String_IsEmpty(self)

    def Clear(self) -> "void":
        return _NCollection.NCollection_Utf16String_Clear(self)

    def Assign(self, theOther: "NCollection_Utf16String") -> "NCollection_UtfString< Standard_Utf16Char > const &":
        return _NCollection.NCollection_Utf16String_Assign(self, theOther)

    def Swap(self, theOther: "NCollection_Utf16String") -> "void":
        return _NCollection.NCollection_Utf16String_Swap(self, theOther)

    def Set(self, *args) -> "NCollection_UtfString< Standard_Utf16Char > const &":
        return _NCollection.NCollection_Utf16String_Set(self, *args)

    def __iadd__(self, theAppend: "NCollection_Utf16String") -> "NCollection_UtfString< Standard_Utf16Char > &":
        return _NCollection.NCollection_Utf16String___iadd__(self, theAppend)

    def __eq__(self, theCompare: "NCollection_Utf16String") -> "bool":
        return _NCollection.NCollection_Utf16String___eq__(self, theCompare)

    def __ne__(self, theCompare: "NCollection_Utf16String") -> "bool":
        return _NCollection.NCollection_Utf16String___ne__(self, theCompare)

# Register NCollection_Utf16String in _NCollection:
_NCollection.NCollection_Utf16String_swigregister(NCollection_Utf16String)

class NCollection_Utf32Iter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, theString: "char32_t const *"):
        _NCollection.NCollection_Utf32Iter_swiginit(self, _NCollection.new_NCollection_Utf32Iter(theString))

    def Init(self, theString: "char32_t const *") -> "void":
        return _NCollection.NCollection_Utf32Iter_Init(self, theString)

    def __eq__(self, theRight: "NCollection_Utf32Iter") -> "bool":
        return _NCollection.NCollection_Utf32Iter___eq__(self, theRight)

    def IsValid(self) -> "bool":
        return _NCollection.NCollection_Utf32Iter_IsValid(self)

    def __ref__(self) -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf32Iter___ref__(self)

    def BufferHere(self) -> "char32_t const *":
        return _NCollection.NCollection_Utf32Iter_BufferHere(self)

    def ChangeBufferHere(self) -> "char32_t *":
        return _NCollection.NCollection_Utf32Iter_ChangeBufferHere(self)

    def BufferNext(self) -> "char32_t const *":
        return _NCollection.NCollection_Utf32Iter_BufferNext(self)

    def Index(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32Iter_Index(self)

    def AdvanceBytesUtf8(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32Iter_AdvanceBytesUtf8(self)

    def AdvanceBytesUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32Iter_AdvanceBytesUtf16(self)

    def AdvanceCodeUnitsUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32Iter_AdvanceCodeUnitsUtf16(self)

    def AdvanceBytesUtf32(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32Iter_AdvanceBytesUtf32(self)

    def GetUtf8(self, *args) -> "Standard_Utf8UChar *":
        return _NCollection.NCollection_Utf32Iter_GetUtf8(self, *args)

    def GetUtf16(self, theBuffer: "Standard_Utf16Char *") -> "Standard_Utf16Char *":
        return _NCollection.NCollection_Utf32Iter_GetUtf16(self, theBuffer)

    def GetUtf32(self, theBuffer: "Standard_Utf32Char *") -> "Standard_Utf32Char *":
        return _NCollection.NCollection_Utf32Iter_GetUtf32(self, theBuffer)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf32Iter

# Register NCollection_Utf32Iter in _NCollection:
_NCollection.NCollection_Utf32Iter_swigregister(NCollection_Utf32Iter)

class NCollection_Utf32String(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Iterator(self) -> "NCollection_UtfIterator< char32_t >":
        return _NCollection.NCollection_Utf32String_Iterator(self)

    def Size(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32String_Size(self)

    def Length(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf32String_Length(self)

    def GetChar(self, theCharIndex: "Standard_Integer const") -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf32String_GetChar(self, theCharIndex)

    def GetCharBuffer(self, theCharIndex: "Standard_Integer const") -> "char32_t const *":
        return _NCollection.NCollection_Utf32String_GetCharBuffer(self, theCharIndex)

    def __init__(self, *args):
        _NCollection.NCollection_Utf32String_swiginit(self, _NCollection.new_NCollection_Utf32String(*args))

    def FromLocale(self, theString: "char const *", theLength: "Standard_Integer const"=-1) -> "void":
        return _NCollection.NCollection_Utf32String_FromLocale(self, theString, theLength)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf32String

    def IsEqual(self, theCompare: "NCollection_Utf32String") -> "bool":
        return _NCollection.NCollection_Utf32String_IsEqual(self, theCompare)

    def SubString(self, theStart: "Standard_Integer const", theEnd: "Standard_Integer const") -> "NCollection_UtfString< Standard_Utf32Char >":
        return _NCollection.NCollection_Utf32String_SubString(self, theStart, theEnd)

    def ToCString(self) -> "char32_t const *":
        return _NCollection.NCollection_Utf32String_ToCString(self)

    def ToUtf8(self) -> "NCollection_UtfString< Standard_Utf8Char > const":
        return _NCollection.NCollection_Utf32String_ToUtf8(self)

    def ToUtf16(self) -> "NCollection_UtfString< Standard_Utf16Char > const":
        return _NCollection.NCollection_Utf32String_ToUtf16(self)

    def ToUtf32(self) -> "NCollection_UtfString< Standard_Utf32Char > const":
        return _NCollection.NCollection_Utf32String_ToUtf32(self)

    def ToUtfWide(self) -> "NCollection_UtfString< Standard_WideChar > const":
        return _NCollection.NCollection_Utf32String_ToUtfWide(self)

    def ToLocale(self, theBuffer: "char *", theSizeBytes: "Standard_Integer const") -> "bool":
        return _NCollection.NCollection_Utf32String_ToLocale(self, theBuffer, theSizeBytes)

    def IsEmpty(self) -> "bool":
        return _NCollection.NCollection_Utf32String_IsEmpty(self)

    def Clear(self) -> "void":
        return _NCollection.NCollection_Utf32String_Clear(self)

    def Assign(self, theOther: "NCollection_Utf32String") -> "NCollection_UtfString< Standard_Utf32Char > const &":
        return _NCollection.NCollection_Utf32String_Assign(self, theOther)

    def Swap(self, theOther: "NCollection_Utf32String") -> "void":
        return _NCollection.NCollection_Utf32String_Swap(self, theOther)

    def Set(self, *args) -> "NCollection_UtfString< Standard_Utf32Char > const &":
        return _NCollection.NCollection_Utf32String_Set(self, *args)

    def __iadd__(self, theAppend: "NCollection_Utf32String") -> "NCollection_UtfString< Standard_Utf32Char > &":
        return _NCollection.NCollection_Utf32String___iadd__(self, theAppend)

    def __eq__(self, theCompare: "NCollection_Utf32String") -> "bool":
        return _NCollection.NCollection_Utf32String___eq__(self, theCompare)

    def __ne__(self, theCompare: "NCollection_Utf32String") -> "bool":
        return _NCollection.NCollection_Utf32String___ne__(self, theCompare)

# Register NCollection_Utf32String in _NCollection:
_NCollection.NCollection_Utf32String_swigregister(NCollection_Utf32String)

class NCollection_Utf8Iter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, theString: "char const *"):
        _NCollection.NCollection_Utf8Iter_swiginit(self, _NCollection.new_NCollection_Utf8Iter(theString))

    def Init(self, theString: "char const *") -> "void":
        return _NCollection.NCollection_Utf8Iter_Init(self, theString)

    def __eq__(self, theRight: "NCollection_Utf8Iter") -> "bool":
        return _NCollection.NCollection_Utf8Iter___eq__(self, theRight)

    def IsValid(self) -> "bool":
        return _NCollection.NCollection_Utf8Iter_IsValid(self)

    def __ref__(self) -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf8Iter___ref__(self)

    def BufferHere(self) -> "char const *":
        return _NCollection.NCollection_Utf8Iter_BufferHere(self)

    def ChangeBufferHere(self) -> "char *":
        return _NCollection.NCollection_Utf8Iter_ChangeBufferHere(self)

    def BufferNext(self) -> "char const *":
        return _NCollection.NCollection_Utf8Iter_BufferNext(self)

    def Index(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8Iter_Index(self)

    def AdvanceBytesUtf8(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8Iter_AdvanceBytesUtf8(self)

    def AdvanceBytesUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8Iter_AdvanceBytesUtf16(self)

    def AdvanceCodeUnitsUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8Iter_AdvanceCodeUnitsUtf16(self)

    def AdvanceBytesUtf32(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8Iter_AdvanceBytesUtf32(self)

    def GetUtf8(self, *args) -> "Standard_Utf8UChar *":
        return _NCollection.NCollection_Utf8Iter_GetUtf8(self, *args)

    def GetUtf16(self, theBuffer: "Standard_Utf16Char *") -> "Standard_Utf16Char *":
        return _NCollection.NCollection_Utf8Iter_GetUtf16(self, theBuffer)

    def GetUtf32(self, theBuffer: "Standard_Utf32Char *") -> "Standard_Utf32Char *":
        return _NCollection.NCollection_Utf8Iter_GetUtf32(self, theBuffer)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf8Iter

# Register NCollection_Utf8Iter in _NCollection:
_NCollection.NCollection_Utf8Iter_swigregister(NCollection_Utf8Iter)

class NCollection_Utf8String(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Iterator(self) -> "NCollection_UtfIterator< char >":
        return _NCollection.NCollection_Utf8String_Iterator(self)

    def Size(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8String_Size(self)

    def Length(self) -> "Standard_Integer":
        return _NCollection.NCollection_Utf8String_Length(self)

    def GetChar(self, theCharIndex: "Standard_Integer const") -> "Standard_Utf32Char":
        return _NCollection.NCollection_Utf8String_GetChar(self, theCharIndex)

    def GetCharBuffer(self, theCharIndex: "Standard_Integer const") -> "char const *":
        return _NCollection.NCollection_Utf8String_GetCharBuffer(self, theCharIndex)

    def __init__(self, *args):
        _NCollection.NCollection_Utf8String_swiginit(self, _NCollection.new_NCollection_Utf8String(*args))

    def FromLocale(self, theString: "char const *", theLength: "Standard_Integer const"=-1) -> "void":
        return _NCollection.NCollection_Utf8String_FromLocale(self, theString, theLength)
    __swig_destroy__ = _NCollection.delete_NCollection_Utf8String

    def IsEqual(self, theCompare: "NCollection_Utf8String") -> "bool":
        return _NCollection.NCollection_Utf8String_IsEqual(self, theCompare)

    def SubString(self, theStart: "Standard_Integer const", theEnd: "Standard_Integer const") -> "NCollection_UtfString< Standard_Utf8Char >":
        return _NCollection.NCollection_Utf8String_SubString(self, theStart, theEnd)

    def ToCString(self) -> "char const *":
        return _NCollection.NCollection_Utf8String_ToCString(self)

    def ToUtf8(self) -> "NCollection_UtfString< Standard_Utf8Char > const":
        return _NCollection.NCollection_Utf8String_ToUtf8(self)

    def ToUtf16(self) -> "NCollection_UtfString< Standard_Utf16Char > const":
        return _NCollection.NCollection_Utf8String_ToUtf16(self)

    def ToUtf32(self) -> "NCollection_UtfString< Standard_Utf32Char > const":
        return _NCollection.NCollection_Utf8String_ToUtf32(self)

    def ToUtfWide(self) -> "NCollection_UtfString< Standard_WideChar > const":
        return _NCollection.NCollection_Utf8String_ToUtfWide(self)

    def ToLocale(self, theBuffer: "char *", theSizeBytes: "Standard_Integer const") -> "bool":
        return _NCollection.NCollection_Utf8String_ToLocale(self, theBuffer, theSizeBytes)

    def IsEmpty(self) -> "bool":
        return _NCollection.NCollection_Utf8String_IsEmpty(self)

    def Clear(self) -> "void":
        return _NCollection.NCollection_Utf8String_Clear(self)

    def Assign(self, theOther: "NCollection_Utf8String") -> "NCollection_UtfString< Standard_Utf8Char > const &":
        return _NCollection.NCollection_Utf8String_Assign(self, theOther)

    def Swap(self, theOther: "NCollection_Utf8String") -> "void":
        return _NCollection.NCollection_Utf8String_Swap(self, theOther)

    def Set(self, *args) -> "NCollection_UtfString< Standard_Utf8Char > const &":
        return _NCollection.NCollection_Utf8String_Set(self, *args)

    def __iadd__(self, theAppend: "NCollection_Utf8String") -> "NCollection_UtfString< Standard_Utf8Char > &":
        return _NCollection.NCollection_Utf8String___iadd__(self, theAppend)

    def __eq__(self, theCompare: "NCollection_Utf8String") -> "bool":
        return _NCollection.NCollection_Utf8String___eq__(self, theCompare)

    def __ne__(self, theCompare: "NCollection_Utf8String") -> "bool":
        return _NCollection.NCollection_Utf8String___ne__(self, theCompare)

# Register NCollection_Utf8String in _NCollection:
_NCollection.NCollection_Utf8String_swigregister(NCollection_Utf8String)

class NCollection_UtfWideIter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, theString: "wchar_t const *"):
        _NCollection.NCollection_UtfWideIter_swiginit(self, _NCollection.new_NCollection_UtfWideIter(theString))

    def Init(self, theString: "wchar_t const *") -> "void":
        return _NCollection.NCollection_UtfWideIter_Init(self, theString)

    def __eq__(self, theRight: "NCollection_UtfWideIter") -> "bool":
        return _NCollection.NCollection_UtfWideIter___eq__(self, theRight)

    def IsValid(self) -> "bool":
        return _NCollection.NCollection_UtfWideIter_IsValid(self)

    def __ref__(self) -> "Standard_Utf32Char":
        return _NCollection.NCollection_UtfWideIter___ref__(self)

    def BufferHere(self) -> "wchar_t const *":
        return _NCollection.NCollection_UtfWideIter_BufferHere(self)

    def ChangeBufferHere(self) -> "wchar_t *":
        return _NCollection.NCollection_UtfWideIter_ChangeBufferHere(self)

    def BufferNext(self) -> "wchar_t const *":
        return _NCollection.NCollection_UtfWideIter_BufferNext(self)

    def Index(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideIter_Index(self)

    def AdvanceBytesUtf8(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideIter_AdvanceBytesUtf8(self)

    def AdvanceBytesUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideIter_AdvanceBytesUtf16(self)

    def AdvanceCodeUnitsUtf16(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideIter_AdvanceCodeUnitsUtf16(self)

    def AdvanceBytesUtf32(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideIter_AdvanceBytesUtf32(self)

    def GetUtf8(self, *args) -> "Standard_Utf8UChar *":
        return _NCollection.NCollection_UtfWideIter_GetUtf8(self, *args)

    def GetUtf16(self, theBuffer: "Standard_Utf16Char *") -> "Standard_Utf16Char *":
        return _NCollection.NCollection_UtfWideIter_GetUtf16(self, theBuffer)

    def GetUtf32(self, theBuffer: "Standard_Utf32Char *") -> "Standard_Utf32Char *":
        return _NCollection.NCollection_UtfWideIter_GetUtf32(self, theBuffer)
    __swig_destroy__ = _NCollection.delete_NCollection_UtfWideIter

# Register NCollection_UtfWideIter in _NCollection:
_NCollection.NCollection_UtfWideIter_swigregister(NCollection_UtfWideIter)

class NCollection_UtfWideString(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def Iterator(self) -> "NCollection_UtfIterator< wchar_t >":
        return _NCollection.NCollection_UtfWideString_Iterator(self)

    def Size(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideString_Size(self)

    def Length(self) -> "Standard_Integer":
        return _NCollection.NCollection_UtfWideString_Length(self)

    def GetChar(self, theCharIndex: "Standard_Integer const") -> "Standard_Utf32Char":
        return _NCollection.NCollection_UtfWideString_GetChar(self, theCharIndex)

    def GetCharBuffer(self, theCharIndex: "Standard_Integer const") -> "wchar_t const *":
        return _NCollection.NCollection_UtfWideString_GetCharBuffer(self, theCharIndex)

    def __init__(self, *args):
        _NCollection.NCollection_UtfWideString_swiginit(self, _NCollection.new_NCollection_UtfWideString(*args))

    def FromLocale(self, theString: "char const *", theLength: "Standard_Integer const"=-1) -> "void":
        return _NCollection.NCollection_UtfWideString_FromLocale(self, theString, theLength)
    __swig_destroy__ = _NCollection.delete_NCollection_UtfWideString

    def IsEqual(self, theCompare: "NCollection_UtfWideString") -> "bool":
        return _NCollection.NCollection_UtfWideString_IsEqual(self, theCompare)

    def SubString(self, theStart: "Standard_Integer const", theEnd: "Standard_Integer const") -> "NCollection_UtfString< Standard_WideChar >":
        return _NCollection.NCollection_UtfWideString_SubString(self, theStart, theEnd)

    def ToCString(self) -> "wchar_t const *":
        return _NCollection.NCollection_UtfWideString_ToCString(self)

    def ToUtf8(self) -> "NCollection_UtfString< Standard_Utf8Char > const":
        return _NCollection.NCollection_UtfWideString_ToUtf8(self)

    def ToUtf16(self) -> "NCollection_UtfString< Standard_Utf16Char > const":
        return _NCollection.NCollection_UtfWideString_ToUtf16(self)

    def ToUtf32(self) -> "NCollection_UtfString< Standard_Utf32Char > const":
        return _NCollection.NCollection_UtfWideString_ToUtf32(self)

    def ToUtfWide(self) -> "NCollection_UtfString< Standard_WideChar > const":
        return _NCollection.NCollection_UtfWideString_ToUtfWide(self)

    def ToLocale(self, theBuffer: "char *", theSizeBytes: "Standard_Integer const") -> "bool":
        return _NCollection.NCollection_UtfWideString_ToLocale(self, theBuffer, theSizeBytes)

    def IsEmpty(self) -> "bool":
        return _NCollection.NCollection_UtfWideString_IsEmpty(self)

    def Clear(self) -> "void":
        return _NCollection.NCollection_UtfWideString_Clear(self)

    def Assign(self, theOther: "NCollection_UtfWideString") -> "NCollection_UtfString< Standard_WideChar > const &":
        return _NCollection.NCollection_UtfWideString_Assign(self, theOther)

    def Swap(self, theOther: "NCollection_UtfWideString") -> "void":
        return _NCollection.NCollection_UtfWideString_Swap(self, theOther)

    def Set(self, *args) -> "NCollection_UtfString< Standard_WideChar > const &":
        return _NCollection.NCollection_UtfWideString_Set(self, *args)

    def __iadd__(self, theAppend: "NCollection_UtfWideString") -> "NCollection_UtfString< Standard_WideChar > &":
        return _NCollection.NCollection_UtfWideString___iadd__(self, theAppend)

    def __eq__(self, theCompare: "NCollection_UtfWideString") -> "bool":
        return _NCollection.NCollection_UtfWideString___eq__(self, theCompare)

    def __ne__(self, theCompare: "NCollection_UtfWideString") -> "bool":
        return _NCollection.NCollection_UtfWideString___ne__(self, theCompare)

# Register NCollection_UtfWideString in _NCollection:
_NCollection.NCollection_UtfWideString_swigregister(NCollection_UtfWideString)


@classnotwrapped
class NCollection_Array1:
	pass

@classnotwrapped
class NCollection_AccAllocator:
	pass

@classnotwrapped
class NCollection_UtfString:
	pass

@classnotwrapped
class NCollection_Lerp:
	pass

@classnotwrapped
class NCollection_WinHeapAllocator:
	pass

@classnotwrapped
class NCollection_Mat4:
	pass

@classnotwrapped
class NCollection_AlignedAllocator:
	pass

@classnotwrapped
class NCollection_Map:
	pass

@classnotwrapped
class NCollection_SeqNode:
	pass

@classnotwrapped
class NCollection_BaseSequence:
	pass

@classnotwrapped
class NCollection_LocalArray:
	pass

@classnotwrapped
class NCollection_TListNode:
	pass

@classnotwrapped
class NCollection_DataMap:
	pass

@classnotwrapped
class NCollection_ListNode:
	pass

@classnotwrapped
class NCollection_Vector:
	pass

@classnotwrapped
class NCollection_DoubleMap:
	pass

@classnotwrapped
class NCollection_UtfIterator:
	pass

@classnotwrapped
class NCollection_Vec3:
	pass

@classnotwrapped
class NCollection_UBTree:
	pass

@classnotwrapped
class NCollection_EBTree:
	pass

@classnotwrapped
class NCollection_Vec4:
	pass

@classnotwrapped
class NCollection_Handle:
	pass

@classnotwrapped
class NCollection_BaseList:
	pass

@classnotwrapped
class NCollection_SparseArray:
	pass

@classnotwrapped
class NCollection_BaseVector:
	pass

@classnotwrapped
class NCollection_IncAllocator:
	pass

@classnotwrapped
class NCollection_BaseAllocator:
	pass

@classnotwrapped
class NCollection_SparseArrayBase:
	pass

@classnotwrapped
class NCollection_IndexedMap:
	pass

@classnotwrapped
class NCollection_Vec2:
	pass

@classnotwrapped
class NCollection_List:
	pass

@classnotwrapped
class NCollection_TListIterator:
	pass

@classnotwrapped
class NCollection_BaseMap:
	pass

@classnotwrapped
class NCollection_Buffer:
	pass

@classnotwrapped
class NCollection_IndexedDataMap:
	pass

@classnotwrapped
class NCollection_StdAllocator:
	pass

@classnotwrapped
class NCollection_UBTreeFiller:
	pass

@classnotwrapped
class NCollection_DefaultHasher:
	pass

@classnotwrapped
class NCollection_Sequence:
	pass

@classnotwrapped
class NCollection_Array2:
	pass

@classnotwrapped
class NCollection_Shared:
	pass

@classnotwrapped
class NCollection_HeapAllocator:
	pass



NCollection_String=NCollection_Utf8String






from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.Graphic3d import *
from OCC.Core.Poly import *
from OCC.Core.gp import *
from OCC.Core.Bnd import *
from OCC.Core.TCollection import *
from OCC.Core.GeomAbs import *
from OCC.Core.Aspect import *
from OCC.Core.Quantity import *
from OCC.Core.TColStd import *

Graphic3d_HighlightStyle = NewType('Graphic3d_HighlightStyle', Prs3d_Drawer)
#the following typedef cannot be wrapped as is
Prs3d_NListIteratorOfListOfSequenceOfPnt = NewType('Prs3d_NListIteratorOfListOfSequenceOfPnt', Any)
Prs3d_Presentation = NewType('Prs3d_Presentation', Graphic3d_Structure)

class Prs3d_NListOfSequenceOfPnt:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Prs3d_DimensionTextVerticalPosition(IntEnum):
	Prs3d_DTVP_Above: int = ...
	Prs3d_DTVP_Below: int = ...
	Prs3d_DTVP_Center: int = ...
Prs3d_DTVP_Above = Prs3d_DimensionTextVerticalPosition.Prs3d_DTVP_Above
Prs3d_DTVP_Below = Prs3d_DimensionTextVerticalPosition.Prs3d_DTVP_Below
Prs3d_DTVP_Center = Prs3d_DimensionTextVerticalPosition.Prs3d_DTVP_Center

class Prs3d_TypeOfHighlight(IntEnum):
	Prs3d_TypeOfHighlight_None: int = ...
	Prs3d_TypeOfHighlight_Selected: int = ...
	Prs3d_TypeOfHighlight_Dynamic: int = ...
	Prs3d_TypeOfHighlight_LocalSelected: int = ...
	Prs3d_TypeOfHighlight_LocalDynamic: int = ...
	Prs3d_TypeOfHighlight_SubIntensity: int = ...
	Prs3d_TypeOfHighlight_NB: int = ...
Prs3d_TypeOfHighlight_None = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_None
Prs3d_TypeOfHighlight_Selected = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_Selected
Prs3d_TypeOfHighlight_Dynamic = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_Dynamic
Prs3d_TypeOfHighlight_LocalSelected = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_LocalSelected
Prs3d_TypeOfHighlight_LocalDynamic = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_LocalDynamic
Prs3d_TypeOfHighlight_SubIntensity = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_SubIntensity
Prs3d_TypeOfHighlight_NB = Prs3d_TypeOfHighlight.Prs3d_TypeOfHighlight_NB

class Prs3d_VertexDrawMode(IntEnum):
	Prs3d_VDM_Isolated: int = ...
	Prs3d_VDM_All: int = ...
	Prs3d_VDM_Inherited: int = ...
Prs3d_VDM_Isolated = Prs3d_VertexDrawMode.Prs3d_VDM_Isolated
Prs3d_VDM_All = Prs3d_VertexDrawMode.Prs3d_VDM_All
Prs3d_VDM_Inherited = Prs3d_VertexDrawMode.Prs3d_VDM_Inherited

class Prs3d_DatumMode(IntEnum):
	Prs3d_DM_WireFrame: int = ...
	Prs3d_DM_Shaded: int = ...
Prs3d_DM_WireFrame = Prs3d_DatumMode.Prs3d_DM_WireFrame
Prs3d_DM_Shaded = Prs3d_DatumMode.Prs3d_DM_Shaded

class Prs3d_DatumAttribute(IntEnum):
	Prs3d_DA_XAxisLength: int = ...
	Prs3d_DA_YAxisLength: int = ...
	Prs3d_DA_ZAxisLength: int = ...
	Prs3d_DP_ShadingTubeRadiusPercent: int = ...
	Prs3d_DP_ShadingConeRadiusPercent: int = ...
	Prs3d_DP_ShadingConeLengthPercent: int = ...
	Prs3d_DP_ShadingOriginRadiusPercent: int = ...
	Prs3d_DP_ShadingNumberOfFacettes: int = ...
Prs3d_DA_XAxisLength = Prs3d_DatumAttribute.Prs3d_DA_XAxisLength
Prs3d_DA_YAxisLength = Prs3d_DatumAttribute.Prs3d_DA_YAxisLength
Prs3d_DA_ZAxisLength = Prs3d_DatumAttribute.Prs3d_DA_ZAxisLength
Prs3d_DP_ShadingTubeRadiusPercent = Prs3d_DatumAttribute.Prs3d_DP_ShadingTubeRadiusPercent
Prs3d_DP_ShadingConeRadiusPercent = Prs3d_DatumAttribute.Prs3d_DP_ShadingConeRadiusPercent
Prs3d_DP_ShadingConeLengthPercent = Prs3d_DatumAttribute.Prs3d_DP_ShadingConeLengthPercent
Prs3d_DP_ShadingOriginRadiusPercent = Prs3d_DatumAttribute.Prs3d_DP_ShadingOriginRadiusPercent
Prs3d_DP_ShadingNumberOfFacettes = Prs3d_DatumAttribute.Prs3d_DP_ShadingNumberOfFacettes

class Prs3d_DimensionTextHorizontalPosition(IntEnum):
	Prs3d_DTHP_Left: int = ...
	Prs3d_DTHP_Right: int = ...
	Prs3d_DTHP_Center: int = ...
	Prs3d_DTHP_Fit: int = ...
Prs3d_DTHP_Left = Prs3d_DimensionTextHorizontalPosition.Prs3d_DTHP_Left
Prs3d_DTHP_Right = Prs3d_DimensionTextHorizontalPosition.Prs3d_DTHP_Right
Prs3d_DTHP_Center = Prs3d_DimensionTextHorizontalPosition.Prs3d_DTHP_Center
Prs3d_DTHP_Fit = Prs3d_DimensionTextHorizontalPosition.Prs3d_DTHP_Fit

class Prs3d_TypeOfLinePicking(IntEnum):
	Prs3d_TOLP_Point: int = ...
	Prs3d_TOLP_Segment: int = ...
Prs3d_TOLP_Point = Prs3d_TypeOfLinePicking.Prs3d_TOLP_Point
Prs3d_TOLP_Segment = Prs3d_TypeOfLinePicking.Prs3d_TOLP_Segment

class Prs3d_TypeOfHLR(IntEnum):
	Prs3d_TOH_NotSet: int = ...
	Prs3d_TOH_PolyAlgo: int = ...
	Prs3d_TOH_Algo: int = ...
Prs3d_TOH_NotSet = Prs3d_TypeOfHLR.Prs3d_TOH_NotSet
Prs3d_TOH_PolyAlgo = Prs3d_TypeOfHLR.Prs3d_TOH_PolyAlgo
Prs3d_TOH_Algo = Prs3d_TypeOfHLR.Prs3d_TOH_Algo

class Prs3d_DatumAxes(IntEnum):
	Prs3d_DA_XAxis: int = ...
	Prs3d_DA_YAxis: int = ...
	Prs3d_DA_ZAxis: int = ...
	Prs3d_DA_XYAxis: int = ...
	Prs3d_DA_YZAxis: int = ...
	Prs3d_DA_XZAxis: int = ...
	Prs3d_DA_XYZAxis: int = ...
Prs3d_DA_XAxis = Prs3d_DatumAxes.Prs3d_DA_XAxis
Prs3d_DA_YAxis = Prs3d_DatumAxes.Prs3d_DA_YAxis
Prs3d_DA_ZAxis = Prs3d_DatumAxes.Prs3d_DA_ZAxis
Prs3d_DA_XYAxis = Prs3d_DatumAxes.Prs3d_DA_XYAxis
Prs3d_DA_YZAxis = Prs3d_DatumAxes.Prs3d_DA_YZAxis
Prs3d_DA_XZAxis = Prs3d_DatumAxes.Prs3d_DA_XZAxis
Prs3d_DA_XYZAxis = Prs3d_DatumAxes.Prs3d_DA_XYZAxis

class Prs3d_DatumParts(IntEnum):
	Prs3d_DP_Origin: int = ...
	Prs3d_DP_XAxis: int = ...
	Prs3d_DP_YAxis: int = ...
	Prs3d_DP_ZAxis: int = ...
	Prs3d_DP_XArrow: int = ...
	Prs3d_DP_YArrow: int = ...
	Prs3d_DP_ZArrow: int = ...
	Prs3d_DP_XOYAxis: int = ...
	Prs3d_DP_YOZAxis: int = ...
	Prs3d_DP_XOZAxis: int = ...
	Prs3d_DP_None: int = ...
Prs3d_DP_Origin = Prs3d_DatumParts.Prs3d_DP_Origin
Prs3d_DP_XAxis = Prs3d_DatumParts.Prs3d_DP_XAxis
Prs3d_DP_YAxis = Prs3d_DatumParts.Prs3d_DP_YAxis
Prs3d_DP_ZAxis = Prs3d_DatumParts.Prs3d_DP_ZAxis
Prs3d_DP_XArrow = Prs3d_DatumParts.Prs3d_DP_XArrow
Prs3d_DP_YArrow = Prs3d_DatumParts.Prs3d_DP_YArrow
Prs3d_DP_ZArrow = Prs3d_DatumParts.Prs3d_DP_ZArrow
Prs3d_DP_XOYAxis = Prs3d_DatumParts.Prs3d_DP_XOYAxis
Prs3d_DP_YOZAxis = Prs3d_DatumParts.Prs3d_DP_YOZAxis
Prs3d_DP_XOZAxis = Prs3d_DatumParts.Prs3d_DP_XOZAxis
Prs3d_DP_None = Prs3d_DatumParts.Prs3d_DP_None

class Prs3d_DimensionArrowOrientation(IntEnum):
	Prs3d_DAO_Internal: int = ...
	Prs3d_DAO_External: int = ...
	Prs3d_DAO_Fit: int = ...
Prs3d_DAO_Internal = Prs3d_DimensionArrowOrientation.Prs3d_DAO_Internal
Prs3d_DAO_External = Prs3d_DimensionArrowOrientation.Prs3d_DAO_External
Prs3d_DAO_Fit = Prs3d_DimensionArrowOrientation.Prs3d_DAO_Fit

class prs3d:
	@staticmethod
	def AddFreeEdges(theSegments: TColgp_SequenceOfPnt, thePolyTri: Poly_Triangulation, theLocation: gp_Trsf) -> None: ...
	@staticmethod
	def AddPrimitivesGroup(thePrs: Prs3d_Presentation, theAspect: Prs3d_LineAspect, thePolylines: Prs3d_NListOfSequenceOfPnt) -> None: ...
	@overload
	@staticmethod
	def GetDeflection(theBndMin: Graphic3d_Vec3d, theBndMax: Graphic3d_Vec3d, theDeviationCoefficient: float) -> float: ...
	@overload
	@staticmethod
	def GetDeflection(theBndBox: Bnd_Box, theDeviationCoefficient: float, theMaximalChordialDeviation: float) -> float: ...
	@staticmethod
	def MatchSegment(X: float, Y: float, Z: float, aDistance: float, p1: gp_Pnt, p2: gp_Pnt) -> Tuple[bool, float]: ...
	@staticmethod
	def PrimitivesFromPolylines(thePoints: Prs3d_NListOfSequenceOfPnt) -> Graphic3d_ArrayOfPrimitives: ...

class Prs3d_Arrow:
	@overload
	@staticmethod
	def Draw(theGroup: Graphic3d_Group, theLocation: gp_Pnt, theDirection: gp_Dir, theAngle: float, theLength: float) -> None: ...
	@overload
	@staticmethod
	def Draw(thePrs: Prs3d_Presentation, theLocation: gp_Pnt, theDirection: gp_Dir, theAngle: float, theLength: float) -> None: ...
	@staticmethod
	def DrawSegments(theLocation: gp_Pnt, theDir: gp_Dir, theAngle: float, theLength: float, theNbSegments: int) -> Graphic3d_ArrayOfSegments: ...
	@staticmethod
	def DrawShaded(theAxis: gp_Ax1, theTubeRadius: float, theAxisLength: float, theConeRadius: float, theConeLength: float, theNbFacettes: int) -> Graphic3d_ArrayOfTriangles: ...

class Prs3d_BasicAspect(Standard_Transient):
	pass

class Prs3d_DimensionUnits:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theUnits: Prs3d_DimensionUnits) -> None: ...
	def GetAngleUnits(self) -> TCollection_AsciiString: ...
	def GetLengthUnits(self) -> TCollection_AsciiString: ...
	def SetAngleUnits(self, theUnits: TCollection_AsciiString) -> None: ...
	def SetLengthUnits(self, theUnits: TCollection_AsciiString) -> None: ...

class Prs3d_Drawer(Graphic3d_PresentationAttributes):
	def __init__(self) -> None: ...
	def ArrowAspect(self) -> Prs3d_ArrowAspect: ...
	def ClearLocalAttributes(self) -> None: ...
	def DatumAspect(self) -> Prs3d_DatumAspect: ...
	def DeviationAngle(self) -> float: ...
	def DeviationCoefficient(self) -> float: ...
	def DimAngleDisplayUnits(self) -> TCollection_AsciiString: ...
	def DimAngleModelUnits(self) -> TCollection_AsciiString: ...
	def DimLengthDisplayUnits(self) -> TCollection_AsciiString: ...
	def DimLengthModelUnits(self) -> TCollection_AsciiString: ...
	def DimensionAspect(self) -> Prs3d_DimensionAspect: ...
	def DisableDrawHiddenLine(self) -> None: ...
	def Discretisation(self) -> int: ...
	def DrawHiddenLine(self) -> bool: ...
	def EnableDrawHiddenLine(self) -> None: ...
	def FaceBoundaryAspect(self) -> Prs3d_LineAspect: ...
	def FaceBoundaryDraw(self) -> bool: ...
	def FaceBoundaryUpperContinuity(self) -> GeomAbs_Shape: ...
	def FreeBoundaryAspect(self) -> Prs3d_LineAspect: ...
	def FreeBoundaryDraw(self) -> bool: ...
	def HLRAngle(self) -> float: ...
	def HasLink(self) -> bool: ...
	def HasOwnArrowAspect(self) -> bool: ...
	def HasOwnDatumAspect(self) -> bool: ...
	def HasOwnDeviationAngle(self) -> bool: ...
	def HasOwnDeviationCoefficient(self) -> bool: ...
	def HasOwnDimAngleDisplayUnits(self) -> bool: ...
	def HasOwnDimAngleModelUnits(self) -> bool: ...
	def HasOwnDimLengthDisplayUnits(self) -> bool: ...
	def HasOwnDimLengthModelUnits(self) -> bool: ...
	def HasOwnDimensionAspect(self) -> bool: ...
	def HasOwnDiscretisation(self) -> bool: ...
	def HasOwnDrawHiddenLine(self) -> bool: ...
	def HasOwnFaceBoundaryAspect(self) -> bool: ...
	def HasOwnFaceBoundaryDraw(self) -> bool: ...
	def HasOwnFaceBoundaryUpperContinuity(self) -> bool: ...
	def HasOwnFreeBoundaryAspect(self) -> bool: ...
	def HasOwnFreeBoundaryDraw(self) -> bool: ...
	def HasOwnHLRDeviationAngle(self) -> bool: ...
	def HasOwnHiddenLineAspect(self) -> bool: ...
	def HasOwnIsAutoTriangulation(self) -> bool: ...
	def HasOwnIsoOnPlane(self) -> bool: ...
	def HasOwnIsoOnTriangulation(self) -> bool: ...
	def HasOwnLineArrowDraw(self) -> bool: ...
	def HasOwnLineAspect(self) -> bool: ...
	def HasOwnMaximalChordialDeviation(self) -> bool: ...
	def HasOwnMaximalParameterValue(self) -> bool: ...
	def HasOwnPlaneAspect(self) -> bool: ...
	def HasOwnPointAspect(self) -> bool: ...
	def HasOwnSectionAspect(self) -> bool: ...
	def HasOwnSeenLineAspect(self) -> bool: ...
	def HasOwnShadingAspect(self) -> bool: ...
	def HasOwnTextAspect(self) -> bool: ...
	def HasOwnTypeOfDeflection(self) -> bool: ...
	def HasOwnTypeOfHLR(self) -> bool: ...
	def HasOwnUIsoAspect(self) -> bool: ...
	def HasOwnUnFreeBoundaryAspect(self) -> bool: ...
	def HasOwnUnFreeBoundaryDraw(self) -> bool: ...
	def HasOwnVIsoAspect(self) -> bool: ...
	def HasOwnVectorAspect(self) -> bool: ...
	def HasOwnVertexDrawMode(self) -> bool: ...
	def HasOwnWireAspect(self) -> bool: ...
	def HasOwnWireDraw(self) -> bool: ...
	def HiddenLineAspect(self) -> Prs3d_LineAspect: ...
	def IsAutoTriangulation(self) -> bool: ...
	def IsoOnPlane(self) -> bool: ...
	def IsoOnTriangulation(self) -> bool: ...
	def LineArrowDraw(self) -> bool: ...
	def LineAspect(self) -> Prs3d_LineAspect: ...
	@overload
	def Link(self) -> Prs3d_Drawer: ...
	@overload
	def Link(self, theDrawer: Prs3d_Drawer) -> None: ...
	def MaximalChordialDeviation(self) -> float: ...
	def MaximalParameterValue(self) -> float: ...
	def PlaneAspect(self) -> Prs3d_PlaneAspect: ...
	def PointAspect(self) -> Prs3d_PointAspect: ...
	def PreviousDeviationAngle(self) -> float: ...
	def PreviousDeviationCoefficient(self) -> float: ...
	def PreviousHLRDeviationAngle(self) -> float: ...
	def SectionAspect(self) -> Prs3d_LineAspect: ...
	def SeenLineAspect(self) -> Prs3d_LineAspect: ...
	def SetArrowAspect(self, theAspect: Prs3d_ArrowAspect) -> None: ...
	def SetAutoTriangulation(self, theIsEnabled: bool) -> None: ...
	def SetDatumAspect(self, theAspect: Prs3d_DatumAspect) -> None: ...
	@overload
	def SetDeviationAngle(self, theAngle: float) -> None: ...
	@overload
	def SetDeviationAngle(self) -> None: ...
	@overload
	def SetDeviationCoefficient(self, theCoefficient: float) -> None: ...
	@overload
	def SetDeviationCoefficient(self) -> None: ...
	def SetDimAngleDisplayUnits(self, theUnits: TCollection_AsciiString) -> None: ...
	def SetDimAngleModelUnits(self, theUnits: TCollection_AsciiString) -> None: ...
	def SetDimLengthDisplayUnits(self, theUnits: TCollection_AsciiString) -> None: ...
	def SetDimLengthModelUnits(self, theUnits: TCollection_AsciiString) -> None: ...
	def SetDimensionAspect(self, theAspect: Prs3d_DimensionAspect) -> None: ...
	def SetDiscretisation(self, theValue: int) -> None: ...
	def SetFaceBoundaryAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetFaceBoundaryDraw(self, theIsEnabled: bool) -> None: ...
	def SetFaceBoundaryUpperContinuity(self, theMostAllowedEdgeClass: GeomAbs_Shape) -> None: ...
	def SetFreeBoundaryAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetFreeBoundaryDraw(self, theIsEnabled: bool) -> None: ...
	@overload
	def SetHLRAngle(self, theAngle: float) -> None: ...
	@overload
	def SetHLRAngle(self) -> None: ...
	def SetHiddenLineAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetIsoOnPlane(self, theIsEnabled: bool) -> None: ...
	def SetIsoOnTriangulation(self, theToEnable: bool) -> None: ...
	def SetLineArrowDraw(self, theIsEnabled: bool) -> None: ...
	def SetLineAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetLink(self, theDrawer: Prs3d_Drawer) -> None: ...
	def SetMaximalChordialDeviation(self, theChordialDeviation: float) -> None: ...
	def SetMaximalParameterValue(self, theValue: float) -> None: ...
	def SetOwnDatumAspects(self, theDefaults: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> bool: ...
	def SetOwnLineAspects(self, theDefaults: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> bool: ...
	def SetPlaneAspect(self, theAspect: Prs3d_PlaneAspect) -> None: ...
	def SetPointAspect(self, theAspect: Prs3d_PointAspect) -> None: ...
	def SetSectionAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetSeenLineAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetShadingAspect(self, theAspect: Prs3d_ShadingAspect) -> None: ...
	def SetTextAspect(self, theAspect: Prs3d_TextAspect) -> None: ...
	def SetTypeOfDeflection(self, theTypeOfDeflection: Aspect_TypeOfDeflection) -> None: ...
	def SetTypeOfHLR(self, theTypeOfHLR: Prs3d_TypeOfHLR) -> None: ...
	def SetUIsoAspect(self, theAspect: Prs3d_IsoAspect) -> None: ...
	def SetUnFreeBoundaryAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetUnFreeBoundaryDraw(self, theIsEnabled: bool) -> None: ...
	def SetVIsoAspect(self, theAspect: Prs3d_IsoAspect) -> None: ...
	def SetVectorAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetVertexDrawMode(self, theMode: Prs3d_VertexDrawMode) -> None: ...
	def SetWireAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetWireDraw(self, theIsEnabled: bool) -> None: ...
	def SetupOwnFaceBoundaryAspect(self, theDefaults: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> bool: ...
	def SetupOwnPointAspect(self, theDefaults: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> bool: ...
	def SetupOwnShadingAspect(self, theDefaults: Optional[Prs3d_Drawer] = Prs3d_Drawer()) -> bool: ...
	def ShadingAspect(self) -> Prs3d_ShadingAspect: ...
	def TextAspect(self) -> Prs3d_TextAspect: ...
	def TypeOfDeflection(self) -> Aspect_TypeOfDeflection: ...
	def TypeOfHLR(self) -> Prs3d_TypeOfHLR: ...
	def UIsoAspect(self) -> Prs3d_IsoAspect: ...
	def UnFreeBoundaryAspect(self) -> Prs3d_LineAspect: ...
	def UnFreeBoundaryDraw(self) -> bool: ...
	def UnsetFaceBoundaryUpperContinuity(self) -> None: ...
	def UpdatePreviousDeviationAngle(self) -> None: ...
	def UpdatePreviousDeviationCoefficient(self) -> None: ...
	def VIsoAspect(self) -> Prs3d_IsoAspect: ...
	def VectorAspect(self) -> Prs3d_LineAspect: ...
	def VertexDrawMode(self) -> Prs3d_VertexDrawMode: ...
	def WireAspect(self) -> Prs3d_LineAspect: ...
	def WireDraw(self) -> bool: ...

class Prs3d_Point:
	pass

class Prs3d_PresentationShadow(Graphic3d_Structure):
	def __init__(self, theViewer: Graphic3d_StructureManager, thePrs: Graphic3d_Structure) -> None: ...
	def CalculateBoundBox(self) -> None: ...
	def ParentAffinity(self) -> Graphic3d_ViewAffinity: ...
	def ParentId(self) -> int: ...

class Prs3d_Root:
	@staticmethod
	def CurrentGroup(thePrs3d: Prs3d_Presentation) -> Graphic3d_Group: ...
	@staticmethod
	def NewGroup(thePrs3d: Prs3d_Presentation) -> Graphic3d_Group: ...

class Prs3d_Text:
	@overload
	@staticmethod
	def Draw(theGroup: Graphic3d_Group, theAspect: Prs3d_TextAspect, theText: TCollection_ExtendedString, theAttachmentPoint: gp_Pnt) -> Graphic3d_Text: ...
	@overload
	@staticmethod
	def Draw(theGroup: Graphic3d_Group, theAspect: Prs3d_TextAspect, theText: TCollection_ExtendedString, theOrientation: gp_Ax2, theHasOwnAnchor: Optional[bool] = True) -> Graphic3d_Text: ...
	@overload
	@staticmethod
	def Draw(thePrs: Prs3d_Presentation, theDrawer: Prs3d_Drawer, theText: TCollection_ExtendedString, theAttachmentPoint: gp_Pnt) -> None: ...
	@overload
	@staticmethod
	def Draw(thePrs: Prs3d_Presentation, theAspect: Prs3d_TextAspect, theText: TCollection_ExtendedString, theOrientation: gp_Ax2, theHasOwnAnchor: Optional[bool] = True) -> None: ...
	@overload
	@staticmethod
	def Draw(thePrs: Prs3d_Presentation, theAspect: Prs3d_TextAspect, theText: TCollection_ExtendedString, theAttachmentPoint: gp_Pnt) -> None: ...

class Prs3d_ToolQuadric:
	def CreatePolyTriangulation(self, theTrsf: gp_Trsf) -> Poly_Triangulation: ...
	def CreateTriangulation(self, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...
	@overload
	def FillArray(self, theArray: Graphic3d_ArrayOfTriangles, theTrsf: gp_Trsf) -> None: ...
	@overload
	def FillArray(self, theArray: Graphic3d_ArrayOfTriangles, theTriangulation: Poly_Triangulation, theTrsf: gp_Trsf) -> None: ...
	@staticmethod
	def TrianglesNb(theSlicesNb: int, theStacksNb: int) -> int: ...
	@staticmethod
	def VerticesNb(theSlicesNb: int, theStacksNb: int, theIsIndexed: Optional[bool] = True) -> int: ...

class Prs3d_ArrowAspect(Prs3d_BasicAspect):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, anAngle: float, aLength: float) -> None: ...
	@overload
	def __init__(self, theAspect: Graphic3d_AspectLine3d) -> None: ...
	def Angle(self) -> float: ...
	def Aspect(self) -> Graphic3d_AspectLine3d: ...
	def Length(self) -> float: ...
	def SetAngle(self, anAngle: float) -> None: ...
	def SetAspect(self, theAspect: Graphic3d_AspectLine3d) -> None: ...
	def SetColor(self, theColor: Quantity_Color) -> None: ...
	def SetLength(self, theLength: float) -> None: ...

class Prs3d_BndBox(Prs3d_Root):
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theBndBox: Bnd_Box, theDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def Add(thePresentation: Prs3d_Presentation, theBndBox: Bnd_OBB, theDrawer: Prs3d_Drawer) -> None: ...
	@overload
	@staticmethod
	def FillSegments(theBox: Bnd_OBB) -> Graphic3d_ArrayOfSegments: ...
	@overload
	@staticmethod
	def FillSegments(theBox: Bnd_Box) -> Graphic3d_ArrayOfSegments: ...
	@overload
	@staticmethod
	def FillSegments(theSegments: Graphic3d_ArrayOfSegments, theBox: Bnd_OBB) -> None: ...
	@overload
	@staticmethod
	def FillSegments(theSegments: Graphic3d_ArrayOfSegments, theBox: Bnd_Box) -> None: ...
	@staticmethod
	def fillSegments(theSegments: Graphic3d_ArrayOfSegments, theBox: gp_Pnt) -> None: ...

class Prs3d_DatumAspect(Prs3d_BasicAspect):
	def __init__(self) -> None: ...
	def ArrowAspect(self) -> Prs3d_ArrowAspect: ...
	def ArrowPartForAxis(self, thePart: Prs3d_DatumParts) -> Prs3d_DatumParts: ...
	def Attribute(self, theType: Prs3d_DatumAttribute) -> float: ...
	def AxisLength(self, thePart: Prs3d_DatumParts) -> float: ...
	def DatumAxes(self) -> Prs3d_DatumAxes: ...
	def DrawDatumPart(self, thePart: Prs3d_DatumParts) -> bool: ...
	def DrawFirstAndSecondAxis(self) -> bool: ...
	def DrawThirdAxis(self) -> bool: ...
	def FirstAxisAspect(self) -> Prs3d_LineAspect: ...
	def FirstAxisLength(self) -> float: ...
	def LineAspect(self, thePart: Prs3d_DatumParts) -> Prs3d_LineAspect: ...
	def PointAspect(self) -> Prs3d_PointAspect: ...
	def SecondAxisAspect(self) -> Prs3d_LineAspect: ...
	def SecondAxisLength(self) -> float: ...
	def SetArrowAspect(self, theAspect: Prs3d_ArrowAspect) -> None: ...
	def SetAttribute(self, theType: Prs3d_DatumAttribute, theValue: float) -> None: ...
	def SetAxisLength(self, theL1: float, theL2: float, theL3: float) -> None: ...
	def SetDrawArrows(self, theToDraw: bool) -> None: ...
	def SetDrawDatumAxes(self, theType: Prs3d_DatumAxes) -> None: ...
	def SetDrawFirstAndSecondAxis(self, theToDraw: bool) -> None: ...
	def SetDrawLabels(self, theToDraw: bool) -> None: ...
	def SetDrawThirdAxis(self, theToDraw: bool) -> None: ...
	def SetPointAspect(self, theAspect: Prs3d_PointAspect) -> None: ...
	def SetTextAspect(self, theTextAspect: Prs3d_TextAspect) -> None: ...
	def SetToDrawLabels(self, theToDraw: bool) -> None: ...
	def ShadingAspect(self, thePart: Prs3d_DatumParts) -> Prs3d_ShadingAspect: ...
	def TextAspect(self) -> Prs3d_TextAspect: ...
	def ThirdAxisAspect(self) -> Prs3d_LineAspect: ...
	def ThirdAxisLength(self) -> float: ...
	def ToDrawArrows(self) -> bool: ...
	def ToDrawLabels(self) -> bool: ...

class Prs3d_DimensionAspect(Prs3d_BasicAspect):
	def __init__(self) -> None: ...
	def ArrowAspect(self) -> Prs3d_ArrowAspect: ...
	def ArrowOrientation(self) -> Prs3d_DimensionArrowOrientation: ...
	def ArrowTailSize(self) -> float: ...
	def ExtensionSize(self) -> float: ...
	def IsArrows3d(self) -> bool: ...
	def IsText3d(self) -> bool: ...
	def IsTextShaded(self) -> bool: ...
	def IsUnitsDisplayed(self) -> bool: ...
	def LineAspect(self) -> Prs3d_LineAspect: ...
	def MakeArrows3d(self, theIsArrows3d: bool) -> None: ...
	def MakeText3d(self, isText3d: bool) -> None: ...
	def MakeTextShaded(self, theIsTextShaded: bool) -> None: ...
	def MakeUnitsDisplayed(self, theIsDisplayed: bool) -> None: ...
	def SetArrowAspect(self, theAspect: Prs3d_ArrowAspect) -> None: ...
	def SetArrowOrientation(self, theArrowOrient: Prs3d_DimensionArrowOrientation) -> None: ...
	def SetArrowTailSize(self, theSize: float) -> None: ...
	def SetCommonColor(self, theColor: Quantity_Color) -> None: ...
	def SetExtensionSize(self, theSize: float) -> None: ...
	def SetLineAspect(self, theAspect: Prs3d_LineAspect) -> None: ...
	def SetTextAspect(self, theAspect: Prs3d_TextAspect) -> None: ...
	def SetTextHorizontalPosition(self, thePosition: Prs3d_DimensionTextHorizontalPosition) -> None: ...
	def SetTextVerticalPosition(self, thePosition: Prs3d_DimensionTextVerticalPosition) -> None: ...
	def SetValueStringFormat(self, theFormat: TCollection_AsciiString) -> None: ...
	def TextAspect(self) -> Prs3d_TextAspect: ...
	def TextHorizontalPosition(self) -> Prs3d_DimensionTextHorizontalPosition: ...
	def TextVerticalPosition(self) -> Prs3d_DimensionTextVerticalPosition: ...
	def ValueStringFormat(self) -> TCollection_AsciiString: ...

class Prs3d_LineAspect(Prs3d_BasicAspect):
	@overload
	def __init__(self, theColor: Quantity_Color, theType: Aspect_TypeOfLine, theWidth: float) -> None: ...
	@overload
	def __init__(self, theAspect: Graphic3d_AspectLine3d) -> None: ...
	def Aspect(self) -> Graphic3d_AspectLine3d: ...
	def SetAspect(self, theAspect: Graphic3d_AspectLine3d) -> None: ...
	def SetColor(self, theColor: Quantity_Color) -> None: ...
	def SetTypeOfLine(self, theType: Aspect_TypeOfLine) -> None: ...
	def SetWidth(self, theWidth: float) -> None: ...

class Prs3d_PlaneAspect(Prs3d_BasicAspect):
	def __init__(self) -> None: ...
	def ArrowAspect(self) -> Prs3d_LineAspect: ...
	def ArrowsAngle(self) -> float: ...
	def ArrowsLength(self) -> float: ...
	def ArrowsSize(self) -> float: ...
	def DisplayCenterArrow(self) -> bool: ...
	def DisplayEdges(self) -> bool: ...
	def DisplayEdgesArrows(self) -> bool: ...
	def DisplayIso(self) -> bool: ...
	def EdgesAspect(self) -> Prs3d_LineAspect: ...
	def IsoAspect(self) -> Prs3d_LineAspect: ...
	def IsoDistance(self) -> float: ...
	def PlaneXLength(self) -> float: ...
	def PlaneYLength(self) -> float: ...
	def SetArrowsAngle(self, theAngle: float) -> None: ...
	def SetArrowsLength(self, theLength: float) -> None: ...
	def SetArrowsSize(self, theSize: float) -> None: ...
	def SetDisplayCenterArrow(self, theToDraw: bool) -> None: ...
	def SetDisplayEdges(self, theToDraw: bool) -> None: ...
	def SetDisplayEdgesArrows(self, theToDraw: bool) -> None: ...
	def SetDisplayIso(self, theToDraw: bool) -> None: ...
	def SetIsoDistance(self, theL: float) -> None: ...
	def SetPlaneLength(self, theLX: float, theLY: float) -> None: ...

class Prs3d_PointAspect(Prs3d_BasicAspect):
	@overload
	def __init__(self, theType: Aspect_TypeOfMarker, theColor: Quantity_Color, theScale: float) -> None: ...
	@overload
	def __init__(self, theColor: Quantity_Color, theWidth: int, theHeight: int, theTexture: TColStd_HArray1OfByte) -> None: ...
	@overload
	def __init__(self, theAspect: Graphic3d_AspectMarker3d) -> None: ...
	def Aspect(self) -> Graphic3d_AspectMarker3d: ...
	def GetTexture(self) -> Graphic3d_MarkerImage: ...
	def GetTextureSize(self) -> Tuple[int, int]: ...
	def SetAspect(self, theAspect: Graphic3d_AspectMarker3d) -> None: ...
	def SetColor(self, theColor: Quantity_Color) -> None: ...
	def SetScale(self, theScale: float) -> None: ...
	def SetTypeOfMarker(self, theType: Aspect_TypeOfMarker) -> None: ...

class Prs3d_ShadingAspect(Prs3d_BasicAspect):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAspect: Graphic3d_AspectFillArea3d) -> None: ...
	def Aspect(self) -> Graphic3d_AspectFillArea3d: ...
	def Color(self, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_FRONT_SIDE) -> Quantity_Color: ...
	def Material(self, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_FRONT_SIDE) -> Graphic3d_MaterialAspect: ...
	def SetAspect(self, theAspect: Graphic3d_AspectFillArea3d) -> None: ...
	def SetColor(self, aColor: Quantity_Color, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_BOTH_SIDE) -> None: ...
	def SetMaterial(self, aMaterial: Graphic3d_MaterialAspect, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_BOTH_SIDE) -> None: ...
	def SetTransparency(self, aValue: float, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_BOTH_SIDE) -> None: ...
	def Transparency(self, aModel: Optional[Aspect_TypeOfFacingModel] = Aspect_TOFM_FRONT_SIDE) -> float: ...

class Prs3d_TextAspect(Prs3d_BasicAspect):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theAspect: Graphic3d_AspectText3d) -> None: ...
	def Angle(self) -> float: ...
	def Aspect(self) -> Graphic3d_AspectText3d: ...
	def Height(self) -> float: ...
	def HorizontalJustification(self) -> Graphic3d_HorizontalTextAlignment: ...
	def Orientation(self) -> Graphic3d_TextPath: ...
	def SetAngle(self, theAngle: float) -> None: ...
	def SetAspect(self, theAspect: Graphic3d_AspectText3d) -> None: ...
	def SetColor(self, theColor: Quantity_Color) -> None: ...
	def SetFont(self, theFont: str) -> None: ...
	def SetHeight(self, theHeight: float) -> None: ...
	def SetHorizontalJustification(self, theJustification: Graphic3d_HorizontalTextAlignment) -> None: ...
	def SetOrientation(self, theOrientation: Graphic3d_TextPath) -> None: ...
	def SetVerticalJustification(self, theJustification: Graphic3d_VerticalTextAlignment) -> None: ...
	def VerticalJustification(self) -> Graphic3d_VerticalTextAlignment: ...

class Prs3d_ToolCylinder(Prs3d_ToolQuadric):
	def __init__(self, theBottomRad: float, theTopRad: float, theHeight: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@staticmethod
	def Create(theBottomRad: float, theTopRad: float, theHeight: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...

class Prs3d_ToolDisk(Prs3d_ToolQuadric):
	def __init__(self, theInnerRadius: float, theOuterRadius: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@staticmethod
	def Create(theInnerRadius: float, theOuterRadius: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...
	def SetAngleRange(self, theStartAngle: float, theEndAngle: float) -> None: ...

class Prs3d_ToolSector(Prs3d_ToolQuadric):
	def __init__(self, theRadius: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@staticmethod
	def Create(theRadius: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...

class Prs3d_ToolSphere(Prs3d_ToolQuadric):
	def __init__(self, theRadius: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@staticmethod
	def Create(theRadius: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...

class Prs3d_ToolTorus(Prs3d_ToolQuadric):
	@overload
	def __init__(self, theMajorRad: float, theMinorRad: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@overload
	def __init__(self, theMajorRad: float, theMinorRad: float, theAngle: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@overload
	def __init__(self, theMajorRad: float, theMinorRad: float, theAngle1: float, theAngle2: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@overload
	def __init__(self, theMajorRad: float, theMinorRad: float, theAngle1: float, theAngle2: float, theAngle: float, theNbSlices: int, theNbStacks: int) -> None: ...
	@overload
	@staticmethod
	def Create(theMajorRad: float, theMinorRad: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...
	@overload
	@staticmethod
	def Create(theMajorRad: float, theMinorRad: float, theAngle: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...
	@overload
	@staticmethod
	def Create(theMajorRad: float, theMinorRad: float, theAngle1: float, theAngle2: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...
	@overload
	@staticmethod
	def Create(theMajorRad: float, theMinorRad: float, theAngle1: float, theAngle2: float, theAngle: float, theNbSlices: int, theNbStacks: int, theTrsf: gp_Trsf) -> Graphic3d_ArrayOfTriangles: ...

class Prs3d_IsoAspect(Prs3d_LineAspect):
	def __init__(self, theColor: Quantity_Color, theType: Aspect_TypeOfLine, theWidth: float, theNumber: int) -> None: ...
	def Number(self) -> int: ...
	def SetNumber(self, theNumber: int) -> None: ...

#classnotwrapped
class Prs3d_ShapeTool: ...

# harray1 classes
# harray2 classes
# hsequence classes

prs3d_AddFreeEdges = prs3d.AddFreeEdges
prs3d_AddPrimitivesGroup = prs3d.AddPrimitivesGroup
prs3d_GetDeflection = prs3d.GetDeflection
prs3d_GetDeflection = prs3d.GetDeflection
prs3d_MatchSegment = prs3d.MatchSegment
prs3d_PrimitivesFromPolylines = prs3d.PrimitivesFromPolylines
Prs3d_Arrow_Draw = Prs3d_Arrow.Draw
Prs3d_Arrow_Draw = Prs3d_Arrow.Draw
Prs3d_Arrow_DrawSegments = Prs3d_Arrow.DrawSegments
Prs3d_Arrow_DrawShaded = Prs3d_Arrow.DrawShaded
Prs3d_Point_Add = Prs3d_Point.Add
Prs3d_Point_Match = Prs3d_Point.Match
Prs3d_Root_CurrentGroup = Prs3d_Root.CurrentGroup
Prs3d_Root_NewGroup = Prs3d_Root.NewGroup
Prs3d_Text_Draw = Prs3d_Text.Draw
Prs3d_Text_Draw = Prs3d_Text.Draw
Prs3d_Text_Draw = Prs3d_Text.Draw
Prs3d_Text_Draw = Prs3d_Text.Draw
Prs3d_Text_Draw = Prs3d_Text.Draw
Prs3d_ToolQuadric_TrianglesNb = Prs3d_ToolQuadric.TrianglesNb
Prs3d_ToolQuadric_VerticesNb = Prs3d_ToolQuadric.VerticesNb
Prs3d_BndBox_Add = Prs3d_BndBox.Add
Prs3d_BndBox_Add = Prs3d_BndBox.Add
Prs3d_BndBox_FillSegments = Prs3d_BndBox.FillSegments
Prs3d_BndBox_FillSegments = Prs3d_BndBox.FillSegments
Prs3d_BndBox_FillSegments = Prs3d_BndBox.FillSegments
Prs3d_BndBox_FillSegments = Prs3d_BndBox.FillSegments
Prs3d_BndBox_fillSegments = Prs3d_BndBox.fillSegments
Prs3d_ToolCylinder_Create = Prs3d_ToolCylinder.Create
Prs3d_ToolDisk_Create = Prs3d_ToolDisk.Create
Prs3d_ToolSector_Create = Prs3d_ToolSector.Create
Prs3d_ToolSphere_Create = Prs3d_ToolSphere.Create
Prs3d_ToolTorus_Create = Prs3d_ToolTorus.Create
Prs3d_ToolTorus_Create = Prs3d_ToolTorus.Create
Prs3d_ToolTorus_Create = Prs3d_ToolTorus.Create
Prs3d_ToolTorus_Create = Prs3d_ToolTorus.Create
